OC.L10N.register(
    "spreed",
    {
    "a conversation" : "Eine Unterhaltung",
    "(Duration %s)" : "(Dauer %s)",
    "You attended a call with {user1}" : "Du hast an einem Anruf mit {user1} teilgenommen",
    "_%n guest_::_%n guests_" : ["%n Gast","%n Gäste"],
    "You attended a call with {user1} and {user2}" : "Du hast an einem Anruf mit {user1} und {user2} teilgenommen",
    "You attended a call with {user1}, {user2} and {user3}" : "Du hast an einem Anruf mit {user1}, {user2} und {user3} teilgenommen",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Du hast an einem Anruf mit {user1}, {user2}, {user3} und {user4} teilgenommen",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Du hast an einem Anruf mit {user1}, {user2}, {user3}, {user4} und {user5} teilgenommen",
    "_%n other_::_%n others_" : ["%n weiterer","%n weitere"],
    "{actor} invited you to {call}" : "{actor} hat dich zu {call} eingeladen",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Du wurdest zu einer <strong>Unterhaltung</strong> eingeladen oder hattest einen <strong>Anruf</strong>",
    "Other activities" : "Andere Aktivitäten",
    "Talk" : "Talk",
    "Guest" : "Gast",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Willkommen bei Nextcloud Talk!\nDiese Unterhaltung informiert über neue Funktionen in Nextcloud Talk.",
    "## New in Talk %s" : "## Neu in Talk %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge und Safari können jetzt zur Teilnahme an Audio- und Videoanrufen verwendet werden",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Eins-zu-Eins-Unterhaltungen sind jetzt dauerhaft und können nicht mehr versehentlich in eine Gruppenunterhaltung gewandelt werden. Wenn ein Teilnehmer eine Unterhaltung verlässt, so wird die Unterhaltung jetzt nicht mehr automatisch gelöscht. Nur wenn beide Teilnehmer gehen, so wird die Unterhaltung vom Server gelöscht",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Jetzt können alle Teilnehmer durch das Posten von \"@all\" in den Chat benachrichtigt werden",
    "- With the \"arrow-up\" key you can repost your last message" : "- Mit der \"Pfeil nach oben\"-Taste kannst du deine letzte Nachricht nochmals senden",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk beherrscht jetzt Befehle. Sende \"/help\" als Nachricht, um zu sehen, ob die Administration welche eingerichtet hat",
    "- With projects you can create quick links between conversations, files and other items" : "- Mit Projekten kannst du einfach und schnell Verknüpfungen zwischen Unterhaltungen, Dateien und anderen Elementen erstellen",
    "- You can now mention guests in the chat" : "- Du kannst nun Gäste im Chat erwähnen",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Unterhaltungen können jetzt eine Lobby erhalten. Dies erlaubt Moderatoren, dem Chat und dem Anruf beizutreten, um das Meeting vorzubereiten, während andere Benutzer und Gäste in der Lobby warten",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Du kannst jetzt direkt auf Nachrichten antworten, um anderen Benutzern den Kontext deiner Nachrichten anzuzeigen",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Die Suche nach Unterhaltungen und Teilnehmern durchsucht jetzt auch vorhandene Unterhaltungen. Das macht es viel einfacher, vorhergehende Unterhaltungen zu finden",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Wenn die Circles-App installiert ist, können jetzt auch benutzerdefinierte Gruppen zu Unterhaltungen hinzugefügt werden",
    "- Check out the new grid and call view" : "- Schau dir die neue Kachel- und Sprecheransicht an",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Es können jetzt Dateien direkt von deinem Gerät in den Chat hochgeladen und per Drag'n'Drop übertragen werden.",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Geteilte Dateien werden jetzt direkt in der Chatansicht mit den Betrachteranwendungen geöffnet",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Es kann jetzt in der vereinheitlichten Suche in der oberen Leiste nach Chats und Nachrichten gesucht werden",
    "- Spice up your messages with emojis from the emoji picker" : "- Peppe deine Nachrichten mit Emojis aus der Emoji-Auswahl auf",
    "- You can now change your camera and microphone while being in a call" : "- Kamera und Mikrofon können jetzt während des Telefonats gewechselt werden",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Den Unterhaltungen einen Kontext mit einer Beschreibung geben und diese öffnen, damit angemeldete Benutzer diese finden und selbst teilnehmen können",
    "- See a read status and send failed messages again" : "- Lesestatus sehen und fehlgeschlagene Nachrichten erneut senden",
    "- Raise your hand in a call with the R key" : "- Die Hand in einem Anruf durch drücken der Taste R heben",
    "- Join the same conversation and call from multiple devices" : "- Derselben Unterhaltung von verschiedenen Geräten aus beitreten",
    "- Send voice messages, share your location or contact details" : "- Sende Sprachnachrichten, teile deinen Aufenthaltsort oder deine Adressdaten",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Füge Gruppen zu einer Unterhaltung hinzu und die Gruppenmitglieder werden automatisch als Teilnehmer hinzugefügt",
    "- A preview of your audio and video is shown before joining a call" : "- Eine Vorschau deines Audios und Videos wird angezeigt, bevor du einen Anruf tätigst",
    "- You can now blur your background in the newly designed call view" : "- In der neu gestalteten Anrufansicht kannst du jetzt den Hintergrund unscharf anzeigen",
    "- Moderators can now assign general and individual permissions to participants" : "- Moderatoren können nun allgemeine und individuelle Berechtigungen an Teilnehmer vergeben",
    "- You can now react to chat messages" : "- Du kannst jetzt auf Chatnachrichten reagieren",
    "- In the sidebar you can now find an overview of the latest shared items" : "- In der Seitenleiste findest du jetzt eine Übersicht über die zuletzt geteilten Elemente",
    "- Use a poll to collect the opinions of others or settle on a date" : "- eine Umfrage verwenden, um die Meinungen anderer einzuholen oder sich auf einen Zeitpunkt zu einigen",
    "- Configure an expiration time for chat messages" : "- Ablaufdatum für Chatnachrichten konfigurieren",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Anrufe starten, ohne andere in großen Gesprächen zu benachrichtigen. Du kannst einzelne Anrufbenachrichtigungen senden, sobald der Anruf begonnen hat.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Chatnachrichten senden, ohne die Empfänger zu benachrichtigen, für Fälle die nicht dringend sind",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Emojis können jetzt automatisch vervollständigt werden, indem ein \":\" eingegeben wird",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Verknüpfe verschiedene Artikel mit dem neuen Smart-Picker, indem du ein \"/\" eingibst",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Moderatoren können jetzt Gruppenräume erstellen (erfordert das Hochleistungs-Backend)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Anrufe können jetzt aufgezeichnet werden (erfordert das Hochleistungs-Backend)",
    "- Conversations can now have an avatar or emoji as icon" : "- Unterhaltungen können nun einen Avatar oder ein Icon haben",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Virtuelle Hintergründe sind nun zusätzlich zum verwischten Hintergrund in Video-Unterhaltungen möglich",
    "- Reactions are now available during calls" : "- Reaktionen sind nun auch in Anrufen möglich",
    "- Typing indicators show which users are currently typing a message" : "- Schreibindikatoren zeigen, welche Benutzer dabei sind, eine Nachricht zu schreiben",
    "- Groups can now be mentioned in chats" : "- Gruppen können nun in Chats erwähnt werden",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Anrufaufnahmen werden automatisch transkribiert, wenn eine entsprechende Anbieterapp registriert ist",
    "- Chat messages can be translated if a translation provider app is registered" : "- Chatnachrichten können übersetzt werden, wenn eine Übersetzungsanbieter-App registriert ist",
    "- **Markdown** can now be used in _chat_ messages" : "- **Markdown** kann jetzt in  _Chat_nachrichten verwendet werden",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "– Zur Implementierung von Bots stehen jetzt Webhooks zur Verfügung. Weitere Informationen findest du in der Dokumentation: https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Lege eine Erinnerung für eine Chatnachricht fest, um später erneut benachrichtigt zu werden",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Verwende die **Notiz an mich**-Unterhaltung, um Notizen zu machen und Informationen zwischen deinen Geräten auszutauschen",
    "- Captions allow to send a message with a file at the same time" : "- Untertitel ermöglichen das gleichzeitige Senden einer Nachricht mit einer Datei",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- Das Video des Sprechers ist jetzt beim Teilen des Bildschirms sichtbar und die Anrufreaktionen sind animiert",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Nachrichten können jetzt 6 Stunden lang von angemeldeten Autoren und Moderatoren bearbeitet werden",
    "- Unsent message drafts are now saved in your browser" : "- Nicht gesendete Nachrichtenentwürfe werden jetzt in Deinem Browser gespeichert-",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- Textchats können jetzt im Verbund mit anderen Talk-Servern geführt werden",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Moderatoren können jetzt Konten und Gäste sperren, um zu verhindern, dass sie erneut an einer Unterhaltung teilnehmen",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- Anstehende Anrufe aus verknüpften Kalenderterminen und Abwesenheitsvertretungen werden jetzt in Unterhaltungen angezeigt",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- Anrufe können jetzt im Verbund mit anderen Talk-Servern getätigt werden (erfordert das Hochleistungs-Backend)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Wir stellen den Nextcloud Talk Desktop-Client für Windows, macOS und Linux vor: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Zusammenfassung von Anrufaufzeichnungen und ungelesenen Nachrichten in Chats mit dem Nextcloud Assistant",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Verbesserte Meetings mit Erkennung von Gästen, die über ihre E-Mail-Adresse eingeladen werden, Import von Teilnehmerlisten, Entwürfen für Umfragen und Herunterladen von Teilnehmerlisten der Anrufe",
    "- Archive conversations to stay focused" : "- Archivieren von Gesprächen, um konzentriert zu bleiben",
    "- Schedule a meeting into your calendar from within a conversation" : "- Eine Besprechung in deinem Kalender aus einer Unterhaltung heraus planen",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Nach Nachrichten der aktuellen Unterhaltung direkt in der rechten Seitenleiste suchen",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- Mit der neuen kompakten Liste siehst du mehr Unterhaltungen auf einen Blick (in den Gesprächseinstellungen aktivieren)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- Besprechungsunterhaltungen werden jetzt mit dem Titel und der Beschreibung aus dem Kalender synchronisiert und mit einem Suchfilter ausgeblendet, bis sie kurz vor dem Beginn stehen",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- Unterhaltungen in den Benachrichtigungseinstellungen als sensibel markieren, um den Inhalt der Nachricht aus der Unterhaltungsliste und den Benachrichtigungen auszublenden",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- Um Push-Benachrichtigungen während \"Bitte nicht stören\" zu erhalten, markiere Unterhaltungen als wichtig",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- Füge andere Teilnehmer zu einem Einzelgespräch hinzu, um im Handumdrehen ein neues Gruppengespräch zu erstellen.",
    "- Use threads to keep your chat and discussions organized" : "- Themen verwenden, um deine Chats und Diskussionen zu organisieren",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- Live-Transkriptionen sind jetzt während des Anrufs verfügbar (erfordert die Live-Transkriptions-ExApp und das Hochleistungs-Backend)",
    "- Moderators can now pin messages so they are kept at the top" : "- die Moderation kann jetzt Nachrichten anheften, sodass diese oben bleiben",
    "- Schedule a message to send it at a later time" : "- Den Versand einer Nachricht zu einem späteren Zeitpunkt planen",
    "- Conversation tags, grouping and sorting to organize the conversation list" : "- Unterhaltungs-Schlagworte, Gruppierung und Sortierung zum Organisieren der Unterhaltungsliste",
    "- Voice-rooms to connect spontaneously" : "- Unterhaltungs-Räume um sich spontan zu verbinden",
    "- Presets for quick conversation configuration during creation" : "- Voreinstellungen für eine schnelle Unterhaltungseinrichtung während der Erstellung",
    "- Direct calls from profile menus for calls within other apps" : "- Direkte Anrufe aus Profilmenüs für Anrufe innerhalb anderer Apps",
    "_All %n participant_::_All %n participants_" : ["Jeder %n Teilnehmer","Alle %n Teilnehmer"],
    "Talk updates ✅" : "Talk Aktualisierungen ✅",
    "Reaction deleted by author" : "Reaktion vom Autor gelöscht",
    "{actor} created the conversation" : "{actor} hat die Unterhaltung erstellt",
    "You created the conversation" : "Du hast die Unterhaltung erstellt",
    "System created the conversation" : "Das System hat die Unterhaltung erstellt",
    "An administrator created the conversation" : "Die Administration hat die Unterhaltung erstellt",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} hat die Unterhaltung von \"%1$s\" nach \"%2$s\" umbenannt",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Du hast die Unterhaltung von \"%1$s\" in \"%2$s\" umbenannt",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Die Administration hat die Unterhaltung von \"%1$s\" nach \"%2$s\" umbenannt",
    "{actor} set the description" : "{actor} hat die Beschreibung gesetzt",
    "You set the description" : "Du hast die Beschreibung gesetzt",
    "An administrator set the description" : "Die Administration hat die Beschreibung gesetzt",
    "{actor} removed the description" : "{actor} hat die Beschreibung entfernt",
    "You removed the description" : "Du hast die Beschreibung entfernt",
    "An administrator removed the description" : "Die Administration hat die Beschreibung entfernt",
    "You started a silent call" : "Du hast einen stillen Anruf gestartet",
    "Outgoing silent call" : "Ausgehender stiller Anruf",
    "{actor} started a silent call" : "{actor} hat einen stillen Anruf gestartet",
    "Incoming silent call" : "Ankommender stiller Anruf",
    "You started a call" : "Du hast einen Anruf begonnen",
    "Outgoing call" : "Ausgehender Anruf",
    "{actor} started a call" : "{actor} hat einen Anruf begonnen",
    "Incoming call" : "Eingehender Anruf",
    "{actor} joined the call" : "{actor} ist dem Anruf beigetreten",
    "You joined the call" : "Du bist dem Anruf beigetreten",
    "{actor} left the call" : "{actor} hat den Anruf verlassen",
    "You left the call" : "Du hast den Anruf verlassen",
    "{actor} unlocked the conversation" : "{actor} hat die Unterhaltung freigegeben",
    "You unlocked the conversation" : "Du hast die Unterhaltung freigegeben",
    "An administrator unlocked the conversation" : "Die Administration hat die Unterhaltung freigegeben",
    "{actor} locked the conversation" : "{actor} hat die Unterhaltung gesperrt",
    "You locked the conversation" : "Du hast die Unterhaltung gesperrt",
    "An administrator locked the conversation" : "Die Administration hat die Unterhaltung gesperrt",
    "{actor} limited the conversation to the current participants" : "{actor} beschränkte das Gespräch auf die aktuellen Teilnehmer",
    "You limited the conversation to the current participants" : "Du hast das Gespräch auf die aktuellen Teilnehmer beschränkt",
    "An administrator limited the conversation to the current participants" : "Die Administration hat das Gespräch auf die aktuellen Teilnehmer beschränkt",
    "{actor} opened the conversation to registered users" : "{actor} öffnete die Unterhaltung für registrierte Benutzer",
    "You opened the conversation to registered users" : "Du hast die Unterhaltung für registrierte Benutzer geöffnet",
    "An administrator opened the conversation to registered users" : "Die Administration hat die Unterhaltung für registrierte Benutzer geöffnet",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} hat die Unterhaltung für registrierte Benutzer und Benutzer, die mit der Gast-App erstellt wurden, geöffnet",
    "You opened the conversation to registered users and users created with the Guests app" : "Du hast die Unterhaltung für registrierte Benutzer und Benutzer, die mit der Gast-App erstellt wurden, geöffnet",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Die Administration hat die Unterhaltung für registrierte Benutzer und Benutzer, die mit der Gast-App erstellt wurden, geöffnet",
    "The conversation is now open to everyone" : "Die Unterhaltung ist nun für jeden geöffnet",
    "{actor} opened the conversation to everyone" : "{actor} hat die Unterhaltung für jeden geöffnet",
    "You opened the conversation to everyone" : "Du hast die Unterhaltung für Jedermann geöffnet",
    "{actor} restricted the conversation to moderators" : "{actor} hat die Unterhaltung auf Moderatoren beschränkt",
    "You restricted the conversation to moderators" : "Du hast die Unterhaltung auf Moderatoren beschränkt",
    "{actor} started breakout rooms" : "{actor} hat Gruppenräume gestartet",
    "You started breakout rooms" : "Du hast Gruppenräume gestartet.",
    "{actor} stopped breakout rooms" : "{actor} hat Gruppenräume beendet",
    "You stopped breakout rooms" : "Du hast Gruppenräume beendet",
    "{actor} allowed guests" : "{actor} hat Gäste zugelassen",
    "You allowed guests" : "Du hast Gäste zugelassen",
    "An administrator allowed guests" : "Die Administration hat Gäste erlaubt",
    "{actor} disallowed guests" : "{actor} hat Gäste untersagt",
    "You disallowed guests" : "Du hast Gäste untersagt",
    "An administrator disallowed guests" : "Die Administration hat den Gastzugriff untersagt",
    "{actor} set a password" : "{actor} hat ein Passwort vergeben",
    "You set a password" : "Du hast ein Passwort vergeben",
    "An administrator set a password" : "Die Administration hat ein Passwort gesetzt",
    "{actor} removed the password" : "{actor} hat das Passwort entfernt",
    "You removed the password" : "Du hast das Passwort entfernt",
    "An administrator removed the password" : "Die Administration hat das Passwort entfernt",
    "{actor} added {user}" : "{actor} hat {user} hinzugefügt",
    "You joined the conversation" : "Du bist der Unterhaltung beigetreten",
    "{actor} joined the conversation" : "{actor} ist der Unterhaltung beigetreten",
    "You added {user}" : "Du hast {user} hinzugefügt",
    "{actor} added you" : "{actor} hat dich hinzugefügt",
    "An administrator added you" : "Die Administration hat dich hinzugefügt",
    "An administrator added {user}" : "Die Administration hat {user} hinzugefügt",
    "You left the conversation" : "Du hast die Unterhaltung verlassen",
    "{actor} left the conversation" : "{actor} hat die Unterhaltung verlassen",
    "{actor} removed {user}" : "{actor} hat {user} entfernt",
    "You removed {user}" : "Du hast {user} entfernt",
    "{actor} removed you" : "{actor} hat dich entfernt",
    "An administrator removed you" : "Die Administration hat dich entfernt",
    "An administrator removed {user}" : "Die Administration hat {user} entfernt",
    "{actor} invited {federated_user}" : "{actor} hat {federated_user} eingeladen",
    "You invited {federated_user}" : "Du hast {federated_user} eingeladen",
    "You accepted the invitation" : "Du hast diese Einladung angenommen",
    "{actor} invited you" : "{actor} hat dich eingeladen",
    "An administrator invited you" : "Die Administration hat dich eingeladen",
    "An administrator invited {federated_user}" : "Die Administration hat {federated_user} eingeladen",
    "{federated_user} accepted the invitation" : "{federated_user} hat die Einladung angenommen",
    "{actor} removed {federated_user}" : "{actor} hat {federated_user} entfernt",
    "You removed {federated_user}" : "Du hast {federated_user} entfernt",
    "You declined the invitation" : "Du hast die Einladung abgelehnt",
    "An administrator removed {federated_user}" : "Die Administration hat {federated_user} entfernt",
    "{federated_user} declined the invitation" : "{federated_user} hat die Einladung abgelehnt",
    "{actor} added group {group}" : "{actor} hat die Gruppe {group} hinzugefügt",
    "You added group {group}" : "Du hast die Gruppe {group} hinzugefügt",
    "An administrator added group {group}" : "Die Administration hat die Gruppe {group} hinzugefügt",
    "{actor} removed group {group}" : "{actor} hat die Gruppe {group} entfernt",
    "You removed group {group}" : "Du hast die Gruppe {group} entfernt",
    "An administrator removed group {group}" : "Die Administration hat die Gruppe {group} entfernt",
    "{actor} added team {circle}" : "{actor} hat das Team {circle} hinzugefügt",
    "You added team {circle}" : "Du hast das Team {circle} hinzugefügt",
    "An administrator added team {circle}" : "Die Administration hat das Team {circle} hinzugefügt",
    "{actor} removed team {circle}" : "{actor} hat das Team {circle} entfernt",
    "You removed team {circle}" : "Du hast das Team {circle} entfernt",
    "An administrator removed team {circle}" : "Die Administration hat das Team {circle} entfernt",
    "{actor} added {phone}" : "{actor} hat {phone} hinzugefügt",
    "You added {phone}" : "Du hast {phone} hinzugefügt",
    "An administrator added {phone}" : "Die Administration hat {phone} hinzgefügt",
    "{actor} removed {phone}" : "{actor} hat {phone} entfernt",
    "You removed {phone}" : "Du hast {phone} entfernt",
    "An administrator removed {phone}" : "Die Administration hat {phone} entfernt",
    "{actor} promoted {user} to moderator" : "{actor} hat {user} Moderationsrechte zugeteilt",
    "You promoted {user} to moderator" : "Du hast {user} Moderationsrechte zugeteilt",
    "{actor} promoted you to moderator" : "{actor} hat dir Moderationsrechte zugeteilt",
    "An administrator promoted you to moderator" : "Die Administration hat dir Moderationsrechte zugeteilt",
    "An administrator promoted {user} to moderator" : "Die Administration hat {user} Moderationsrechte zugeteilt",
    "{actor} demoted {user} from moderator" : "{actor} hat {user} Moderationsrechte entzogen",
    "You demoted {user} from moderator" : "Du hast {user} Moderationsrechte entzogen",
    "{actor} demoted you from moderator" : "{actor} hat dir Moderationsrechte entzogen",
    "An administrator demoted you from moderator" : "Die Administration hat dir Moderationsrechte entzogen",
    "An administrator demoted {user} from moderator" : "Die Administration hat {user} Moderationsrechte entzogen",
    "{actor} shared a file which is no longer available" : "{actor} hat eine Datei geteilt, die nicht mehr vorhanden ist",
    "You shared a file which is no longer available" : "Du hast eine Datei geteilt, die nicht mehr vorhanden ist",
    "File shares are currently not supported in federated conversations" : "Dateifreigaben werden bislang in federierten Unterhaltungen noch nicht unterstützt",
    "The shared location is malformed" : "Der freigegebene Standort ist fehlerhaft",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} hat Matterbridge so eingerichtet, dass diese Unterhaltung mit anderen Chats synchronisiert wird",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Du hast Matterbridge so eingerichtet, dass diese Unterhaltung mit anderen Chats synchronisiert wird",
    "{actor} created thread {title}" : "{actor} hat das Thema {title} erstellt",
    "You created thread {title}" : "Du hast das Thema {title} erstellt",
    "{actor} renamed thread {title}" : "{actor} hat das Thema {title} umbenannt",
    "You renamed thread {title}" : "Du hast das Thema {title} umbenannt",
    "{actor} updated the Matterbridge configuration" : "{actor} hat die Matterbridge-Konfiguration aktualisiert",
    "You updated the Matterbridge configuration" : "Du hast die Matterbridge-Konfiguration aktualisiert",
    "{actor} removed the Matterbridge configuration" : "{actor} hat die Matterbridge-Konfiguration entfernt",
    "You removed the Matterbridge configuration" : "Du hast die Matterbridge-Konfiguration entfernt",
    "{actor} started Matterbridge" : "{actor} hat Matterbridge gestartet",
    "You started Matterbridge" : "Du hast Matterbridge gestartet",
    "{actor} stopped Matterbridge" : "{actor} hat Matterbridge angehalten",
    "You stopped Matterbridge" : "Du hast Matterbridge angehalten",
    "{actor} deleted a message" : "{actor} hat eine Nachricht gelöscht",
    "You deleted a message" : "Du hast eine Nachricht gelöscht",
    "{actor} edited a message" : "{actor} hat eine Nachricht bearbeitet",
    "You edited a message" : "Du hast eine Nachricht bearbeitet",
    "{actor} pinned a message" : "{actor} hat eine Nachricht angepinnt",
    "You pinned a message" : "Du hast eine Nachricht angepinnt",
    "{actor} unpinned a message" : "{actor} hat eine Nachricht gelöst",
    "Message was automatically unpinned" : "Die Nachricht wurde automatisch gelöst.",
    "You unpinned a message" : "Du hast eine Nachricht gelöst",
    "{actor} deleted a reaction" : "{actor} hat eine Reaktion gelöscht",
    "You deleted a reaction" : "Du hast eine Reaktion gelöscht",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Du hast den Ablauf der Nachricht auf %n Woche festgelegt.","Du hast den Ablauf der Nachricht auf %n Wochen festgelegt."],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Du hast  den Ablauf der Nachricht auf %n Tag festgelegt.","Du hast den Ablauf der Nachricht auf %n Tage festgelegt."],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Du hast den Ablauf der Nachricht auf %n Stunde festgelegt.","Du hast den Ablauf der Nachricht auf %n Stunden festgelegt."],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Du hast den Ablauf der Nachricht auf %n Minuten festgelegt.","Du hast den Ablauf der Nachricht auf %n Minuten festgelegt."],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} hat den Ablauf der Nachricht auf %n Woche festgelegt.","{actor} hat den Ablauf der Nachricht auf %n Wochen festgelegt."],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} hat den Ablauf der Nachricht auf %n Tag festgelegt.","{actor} hat den Ablauf der Nachricht auf %n Tage festgelegt."],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} hat den Ablauf der Nachricht auf %n Stunde festgelegt.","{actor} hat den Ablauf der Nachricht auf %n Stunden festgelegt."],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} hat den Ablauf der Nachricht auf %n Minuten festgelegt.","{actor} hat den Ablauf der Nachricht auf %n Minuten festgelegt."],
    "{actor} disabled message expiration" : "{actor} hat den Ablauf von Nachrichten deaktiviert.",
    "You disabled message expiration" : "Du hast den Ablauf von Nachrichten deaktiviert.",
    "{actor} cleared the history of the conversation" : "{actor} hat den Gesprächsverlauf gelöscht",
    "You cleared the history of the conversation" : "Du hast den Gesprächsverlauf gelöscht",
    "{actor} set the conversation picture" : "{actor} hat das Unterhaltungsbild eingestellt",
    "You set the conversation picture" : "Du hast das Unterhaltungsbild eingestellt",
    "{actor} removed the conversation picture" : "{actor} hat das Unterhaltungsbild entfernt",
    "You removed the conversation picture" : "Du hast das Unterhaltungsbild entfernt",
    "{actor} ended the poll {poll}" : "{actor} hat die Umfrage {poll} beendet",
    "You ended the poll {poll}" : "Du hast die Umfrage {poll} beendet",
    "{actor} started the video recording" : "{actor} hat die Videoaufnahme gestartet.",
    "You started the video recording" : "Du hast die Videoaufnahme gestartet.",
    "{actor} stopped the video recording" : "{actor} hat die Videoaufnahme gestoppt.",
    "You stopped the video recording" : "Du hast die Videoaufnahme gestoppt.",
    "{actor} started the audio recording" : "{actor} hat die Audioaufnahme gestartet.",
    "You started the audio recording" : "Du hast die Audioaufnahme gestartet.",
    "{actor} stopped the audio recording" : "{actor} hat die Audioaufnahme gestoppt.",
    "You stopped the audio recording" : "Du hast die Audioaufnahme gestoppt.",
    "The recording failed" : "Aufnahme fehlgeschlagen",
    "Someone voted on the poll {poll}" : "Jemand hat in der Umfrage {poll} abgestimmt",
    "Message deleted by author" : "Nachricht vom Autor gelöscht",
    "Message deleted by {actor}" : "Nachricht von {actor} gelöscht",
    "Message deleted by you" : "Nachricht von dir gelöscht",
    "Deleted user" : "Gelöschter Benutzer",
    "Unknown number" : "Unbekannte Nummer",
    "Administration" : "Administration",
    "System" : "System",
    "%s (guest)" : "%s (Gast) ",
    "Missed call" : "Verpasster Anruf",
    "Unanswered call" : "Unbeantworteter Anruf",
    "Call ended (Duration {duration})" : "Anruf beendet (Dauer {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "Anruf wurde beendet, da die maximale Gesprächsdauer erreicht wurde (Dauer {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} hat den Anruf beendet (Dauer {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["Anruf mit %n Gast wurde beendet, da die maximale Gesprächsdauer erreicht wurde (Dauer {duration})","Anruf mit %n Gästen wurde beendet, da die maximale Gesprächsdauer erreicht wurde (Dauer {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Anruf mit %n Gast wurde beendet (Dauer {duration})","Anruf mit %n Gästen wurde beendet (Dauer {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} hat den Anruf mit %n Gast beendet (Duration {duration})","{actor} hat den Anruf mit %n Gästen beendet (Duration {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "Anruf mit {user1} wurde beendet, da die maximale Gesprächsdauer erreicht wurde (Dauer {duration}) ",
    "Call with {user1} ended (Duration {duration})" : "Anruf mit {user1} beendet (Dauer {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} hat den Anruf mit {user1} beendet (Duration {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "Anruf mit {user1} und {user2} wurde beendet, da die maximale Gesprächsdauer erreicht wurde (Dauer {duration}) ",
    "Call with {user1} and {user2} ended (Duration {duration})" : "Anruf mit {user1} und {user2} wurde beendet (Dauer {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} hat den Anruf mit {user1} und {user2} beendet (Duration {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "Anruf mit {user1}, {user2} und {user3} wurde beendet, da die maximale Gesprächsdauer erreicht wurde (Dauer {duration}) ",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "Anruf mit {user1}, {user2} und {user3} wurde beendet (Dauer {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} hat den Anruf mit {user1}, {user2} und {user3} beendet (Duration {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "Anruf mit {user1}, {user2}, {user3} und {user4} wurde beendet, da die maximale Gesprächsdauer erreicht wurde (Dauer {duration}) ",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "Anruf mit {user1}, {user2}, {user3} und {user4} wurde beendet (Dauer {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} hat den Anruf mit {user1}, {user2}, {user3} und {user4} beendet (Duration {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "Anruf mit {user1}, {user2}, {user3}, {user4} und {user5} wurde beendet, da die maximale Gesprächsdauer erreicht wurde (Dauer {duration}) ",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "Anruf mit {user1}, {user2}, {user3}, {user4} und {user5} wurde beendet (Dauer {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} hat den Anruf mit {user1}, {user2}, {user3}, {user4} und {user5} beendet (Duration {duration})",
    "Message of {user} in {conversation}" : "Nachricht von {user} in {conversation}",
    "Message of {user}" : "Nachricht von {user}",
    "Message of a deleted user in {conversation}" : "Nachricht eines gelöschten Benutzers in {conversation}",
    "Talk conversations" : "Talk Unterhaltungen",
    "Call %s" : "%s anrufen",
    "Chat with %s" : "Mit %s chatten",
    "An error occurred. Please contact your administrator." : "Es ist ein Fehler aufgetreten. Bitte kontaktiere deine Administration.",
    "App disabled" : "App deaktiviert",
    "Conversation subfolders are disabled" : "Unterhaltungsunterordner sind deaktiviert",
    "Storage quota exceeded" : "Speicherkontingent überschritten",
    "Could not prepare conversation folder" : "Unterhaltungsordner konnten nicht vorbereitet werden",
    "File not found" : "Datei nicht gefunden",
    "Path must point to a file" : "Der Pfad muss auf eine Datei verweisen",
    "File is not inside the conversation draft folder for this room" : "Die Datei befindet sich nicht im Unterhaltungsentwurfsordner für diesen Raum",
    "File is not shared, or shared but not with the user" : "Datei ist nicht geteilt oder nicht mit dem Benutzer geteilt",
    "No account available to delete." : "Kein Konto zum Löschen verfügbar.",
    "Poll" : "Umfrage",
    "Password needs to be set" : "Passwort muss festgelegt werden",
    "Uploading the file failed" : "Hochladen der Datei fehlgeschlagen",
    "No image file provided" : "Keine Bilddatei bereitgestellt",
    "File is too big" : "Datei ist zu groß",
    "Invalid file provided" : "Ungültige Datei bereitgestellt",
    "Invalid image" : "Ungültiges Bild",
    "Unknown filetype" : "Unbekannter Dateityp",
    "Talk mentions" : "Talk Erwähnungen",
    "More conversations" : "Weitere Unterhaltungen",
    "Say hi to your friends and colleagues!" : "Begrüße deine Freunde und Kollegen!",
    "No unread mentions" : "Keine ungelesenen Erwähnungen",
    "Call in progress" : "Anruf ist aktiv",
    "You were mentioned" : "Du wurdest erwähnt",
    "Write to conversation" : "An eine Unterhaltung schreiben",
    "Writes event information into a conversation of your choice" : "Schreibt Termininformationen an eine Unterhaltung deiner Wahl",
    "Missing email field in header line" : "Fehlendes E-Mail-Feld in der Kopfzeile",
    "Following lines are invalid: %s" : "Folgende Zeilen sind unzulässig: %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s hat dich zur Unterhaltung \"%2$s\" eingeladen.",
    "You were invited to conversation \"%s\"." : "Du wurdest zur Unterhaltung \"%s\" eingeladen.",
    "Conversation invitation" : "Einladung zu einer Unterhaltung",
    "Scheduled time" : "Geplante Zeit",
    "Description" : "Beschreibung",
    "You can also dial-in via phone with the following details" : "Du kannst dich auch per Telefon mit den folgenden Daten einwählen",
    "Dial-in information" : "Einwahlinformationen",
    "Meeting ID" : "Meeting-ID",
    "Your PIN" : "Deine PIN",
    "Click the button below to join the lobby now." : "Um jetzt der Lobby beizutreten, auf die untenstehende Schaltfläche klicken.",
    "Click the link below to join the lobby now." : "Um jetzt der Lobby beizutreten, auf den unten stehenden Link klicken.",
    "Join lobby for \"%s\"" : "Lobby für \"%s\" beitreten",
    "Click the button below to join the conversation now." : "Um jetzt der Unterhaltung beizutreten, auf die untenstehende Schaltfläche klicken.",
    "Click the link below to join the conversation now." : "Um jetzt der Unterhaltung beizutreten, auf den unten stehenden Link klicken.",
    "Join \"%s\"" : "\"%s\" beitreten",
    "Meeting" : "Meeting",
    "Password request: %s" : "Passwortanforderung: %s",
    "Private conversation" : "Private Unterhaltung",
    "Deleted user (%s)" : "Gelöschter Benutzer (%s)",
    "Failed to upload call recording" : "Anrufaufzeichnung konnte nicht hochgeladen werden",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "Der Aufzeichnungsserver konnte die Aufzeichnung des Anrufs {call} nicht hochladen. Bitte wende dich an die Administration.",
    "Share to chat" : "In Unterhaltung teilen",
    "Dismiss notification" : "Benachrichtigung verwerfen",
    "Call recording now available" : "Anrufaufzeichnung jetzt verfügbar",
    "The recording for the call in {call} was uploaded to {file}." : "Aufnahme der Unterhaltung in {call} wurde als {file} hochgeladen.",
    "Transcript now available" : "Transkript jetzt verfügbar",
    "The transcript for the call in {call} was uploaded to {file}." : "Das Transkript für den Anruf in {call} wurde als {file} hochgeladen.",
    "Failed to transcript call recording" : "Transkription der Anrufaufzeichnung fehlgeschlagen",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "Der Server konnte die Aufzeichnung in {file} für den Anruf in {call} nicht transkribieren. Bitte wende dich an die Administration.",
    "Call summary now available" : "Anrufzusammenfassung ist jetzt verfügbar",
    "The summary for the call in {call} was uploaded to {file}." : "Die Zusammenfassung für den Anruf in {call} wurde als {file} hochgeladen.",
    "Failed to summarize call recording" : "Zusammenfassung der Anrufaufzeichnung fehlgeschlagen",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "Der Server konnte die Aufzeichnung in {file} für den Anruf in {call} nicht zusammenfassen. Bitte wende Dich an die Administration.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} hat dich eingeladen dem {roomName} auf {remoteServer} beizutreten",
    "Accept" : "Annehmen",
    "Decline" : "Ablehnen",
    "{user1} invited you to a federated conversation" : "{user1} hat dich zu einer Federated-Unterhaltung eingeladen",
    "Someone reacted" : "Jemand hat reagiert",
    "New message" : "Neue Nachricht",
    "Reminder" : "Erinnerung",
    "Someone mentioned you" : "Jemand hat dich erwähnt",
    "Notification" : "Benachrichtigung",
    "Someone reacted in a private conversation" : "Jemand hat in einer privaten Unterhaltung reagiert",
    "You received a message in a private conversation" : "Du hast eine Nachricht in einer privaten Unterhaltung erhalten",
    "Reminder in a private conversation" : "Erinnerung in einer privaten Unterhaltung",
    "Someone mentioned you in a private conversation" : "Jemand hat dich in einer privaten Unterhaltung erwähnt",
    "Notification in a private conversation" : "Benachrichtigung in einer privaten Unterhaltung",
    "Reminder: You in {call}" : "Erinnerung: Du in {call}",
    "Reminder: {user} in {call}" : "Erinnerung: {user} in {call}",
    "Reminder: Deleted user in {call}" : "Erinnerung: Gelöschter Benutzer in {call}",
    "Reminder: {guest} (guest) in {call}" : "Erinnerung: {guest} (Gast) in {call}",
    "Reminder: Guest in {call}" : "Erinnerung: Gast in {call}",
    "{user} reacted with {reaction}" : "{user} reagierte mit {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} reagierte mit {reaction} in {call}\n ",
    "Deleted user reacted with {reaction} in {call}" : "Gelöschter Benutzer reagierte mit {reaction} in {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (Gast) reagierte mit {reaction} in {call}",
    "Guest reacted with {reaction} in {call}" : "Gast reagierte mit {reaction} in {call}",
    "{user} in {call}" : "{user} in {call}",
    "Deleted user in {call}" : "Gelöschter Benutzer in {call}",
    "{guest} (guest) in {call}" : "{guest} (Gast) in {call}",
    "Guest in {call}" : "Gast in {call}",
    "{user} sent you a private message" : "{user} hat dir eine private Nachricht gesendet",
    "{user} sent a message in conversation {call}" : "{user} hat eine Nachricht in der Unterhaltung {call} gesendet",
    "A deleted user sent a message in conversation {call}" : "Ein gelöschter Benutzer hat eine Nachricht in der Unterhaltung {call} gesendet",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (guest) hat eine Nachricht in der Unterhaltung {call} gesendet",
    "A guest sent a message in conversation {call}" : "Ein Gast hat eine Nachricht in der Unterhaltung {call} gesendet",
    "{user} replied to your private message" : "{user} hat auf deine private Nachricht geantwortet",
    "{user} replied to your message in conversation {call}" : "{user} hat auf deine Nachricht in der Unterhaltung {call} geantwortet",
    "A deleted user replied to your message in conversation {call}" : "Ein gelöschter Benutzer hat auf deine Nachricht in der Unterhaltung {call} geantwortet",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (guest) hat auf deine Nachricht in der Unterhaltung {call} geantwortet",
    "A guest replied to your message in conversation {call}" : "Ein Gast hat auf deine Nachricht in der Unterhaltung {call} geantwortet",
    "Reminder: You in private conversation {call}" : "Erinnerung: Du in der privaten Unterhaltung {call}",
    "Reminder: A deleted user in private conversation {call}" : "Erinnerung: Ein gelöschter Benutzer in der privaten Unterhaltung {call}",
    "Reminder: {user} in private conversation" : "Erinnerung: {user} in einer privaten Unterhaltung",
    "Reminder: You in conversation {call}" : "Erinnerung: Du in der Unterhaltung {call}",
    "Reminder: {user} in conversation {call}" : "Erinnerung: {user} in der Unterhaltung {call}",
    "Reminder: A deleted user in conversation {call}" : "Erinnerung: Ein gelöschter Benutzer in der Unterhaltung {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Erinnerung: {guest} (Gast) in der Unterhaltung {call}",
    "Reminder: A guest in conversation {call}" : "Erinnerung: Ein Gast in der Unterhaltung {call}",
    "{user} reacted with {reaction} to your private message" : "{user} hat mit {reaction} auf deine private Nachricht reagiert",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} hat mit {reaction} auf deiner Nachricht in der Unterhaltung {call} reagiert",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Ein gelöschter Benutzer hat mit {reaction} auf deine Nachricht in der Unterhaltung {call} reagiert",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (Gast) hat mit {reaction} auf deine Nachricht in der Unterhaltung {call} reagiert",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Ein Gast hat mit {reaction} auf deine Nachricht in der Unterhaltung {call} reagiert",
    "{user} mentioned you in a private conversation" : "{user} hat dich in einer privaten Unterhaltung erwähnt",
    "{user} mentioned group {group} in conversation {call}" : "{user} hat die Gruppe {group} in der Unterhaltung {call} erwähnt",
    "{user} mentioned team {team} in conversation {call}" : "{user} hat das Team {team} in der Unterhaltung {call} erwähnt",
    "{user} mentioned everyone in conversation {call}" : "{user} hat jeden in der Unterhaltung erwähnt {call}",
    "{user} mentioned you in conversation {call}" : "{user} hat dich in einer Unterhaltung erwähnt: {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "Ein gelöschter Benutzer hat die Gruppe {group} in der Unterhaltung {call} erwähnt",
    "A deleted user mentioned team {team} in conversation {call}" : "Ein gelöschter Benutzer hat das Team {team} in der Unterhaltung {call} erwähnt",
    "A deleted user mentioned everyone in conversation {call}" : "Ein gelöschter Benutzer hat jeden in der Unterhaltung {call} erwähnt",
    "A deleted user mentioned you in conversation {call}" : "Ein gelöschter Benutzer hat dich in der Unterhaltung {call} erwähnt",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (guest) erwähnte die Gruppe {group} in der Unterhaltung {call}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (Gast) hat das Team {team} in der Unterhaltung {call} erwähnt",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (guest) hat jeden in der Unterhaltung {call} erwähnt ",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (guest) hat dich in der Unterhaltung {call} erwähnt",
    "A guest mentioned group {group} in conversation {call}" : "Ein Gast erwähnte die Gruppe {group} in der Unterhaltung {call}",
    "A guest mentioned team {team} in conversation {call}" : "Ein Gast hat das Team {team} in der Unterhaltung {call} erwähnt",
    "A guest mentioned everyone in conversation {call}" : "Ein Gast hat alle in der Unterhaltung {call} erwähnt",
    "A guest mentioned you in conversation {call}" : "Ein Gast hat dich in der Unterhaltung {call} erwähnt",
    "View message" : "Nachricht ansehen",
    "Dismiss reminder" : "Erinnerung verwerfen",
    "View chat" : "Chat anzeigen",
    "{user} invited you to a group conversation: {call}" : "{user} hat dich zu einer Gruppenunterhaltung eingeladen: {call}",
    "Join call" : "Anruf beitreten",
    "Answer call" : "Anruf beantworten",
    "{user} would like to talk with you" : "{user} möchte mit dir sprechen",
    "Call back" : "Zurückrufen",
    "You missed a call from {user}" : "Du hast einen Anruf von {user} verpasst",
    "Accept call" : "Anruf annehmen",
    "Incoming phone call from {call}" : "Eingehender Anruf von{call}",
    "You missed a phone call from {call}" : "Du hast einen Anruf von {call} verpasst",
    "A group call has started in {call}" : "Ein Gruppenanruf wurde in {call} gestartet",
    "You missed a group call in {call}" : "Du hast einen Gruppenanruf in {call} verpasst",
    "{email} is requesting the password to access {file}" : "{email} hat das Passwort für den Zugriff auf {file} angefordert",
    "{email} tried to request the password to access {file}" : "{email} hat versucht, das Passwort für den Zugriff auf {file} anzufordern",
    "Someone is requesting the password to access {file}" : "Jemand hat das Passwort für den Zugriff auf {file} angefordert",
    "Someone tried to request the password to access {file}" : "Jemand hat versucht, das Passwort für den Zugriff auf {file} anzufordern",
    "Open settings" : "Einstellungen öffnen",
    "Hosted signaling server added" : "Gehosteter Signalisierungsserver hinzugefügt",
    "The hosted signaling server is now configured and will be used." : "Der gehostete Signalisierungsserver ist jetzt konfiguriert und wird verwendet.",
    "Hosted signaling server removed" : "Gehosteter Signalisierungsserver entfernt",
    "The hosted signaling server was removed and will not be used anymore." : "Der gehostete Signalisierungsserver wurde entfernt und wird nicht mehr verwendet.",
    "Hosted signaling server changed" : "Gehosteter Signalisierungsserver geändert",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Das gehostete Konto des Signalisierungsservers hat den Status von \"{oldstatus}\" in \"{newstatus}\" geändert.",
    "pending" : "Ausstehend",
    "active" : "Aktiv",
    "expired" : "Abgelaufen",
    "blocked" : "Blockiert",
    "error" : "Fehler",
    "The certificate of {host} expires in {days} days" : "Das Zertifikat von {host} läuft in {days} Tagen ab",
    "The certificate of {host} expired" : "Das Zertifikat von {host} ist abgelaufen",
    "Contact via Talk" : "Über Talk kontaktieren",
    "Open Talk" : "Talk öffnen",
    "Call via Talk" : "Anruf über Talk",
    "Default" : "Standard",
    "Send messages, create threads, and start voice and video calls." : "Nachrichten senden, Themen erstellen und Sprach- sowie und Videoanrufe starten.",
    "Presentation" : "Präsentation",
    "Restricted conversation for internal presentations." : "Eingeschränkte Unterhaltung für interne Präsentationen.",
    "Voice room" : "Sprachraum",
    "Directly join the call, ideal for catch-ups or spontaneous meetings." : "Direkt am Anruf teilnehmen, ideal für Nachholtermine oder spontane Treffen.",
    "Webinar" : "Webinar",
    "Restricted conversation with lobby enabled, ideal for public webinars." : "Eingeschränkte Unterhaltung mit aktivierter Lobby, ideal für öffentliche Webinare.",
    "Conversations" : "Unterhaltungen",
    "Messages in current conversation" : "Nachrichten in der aktuellen Unterhaltung",
    "{user}" : "{user}",
    "Messages" : "Nachrichten",
    "{user} in {conversation}" : "{user} in {conversation}",
    "Messages in other conversations" : "Nachrichten in anderen Unterhaltungen",
    "One-to-one rooms always need to show the other users avatar" : "Eins-zu-Eins-Räume müssen immer den Avatar des anderen Benutzers anzeigen",
    "Invalid emoji character" : "Ungültiges Emoji-Zeichen",
    "Invalid background color" : "Ungültige Hintergrundfarbe",
    "Avatar image is not square" : "Benutzerbild ist nicht quadratisch",
    "Room {number}" : "Raum {number}",
    "Favorites" : "Favoriten",
    "Other" : "Sonstiges",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Trial-Test konnte nicht angefordert werden, da der Testserver nicht erreichbar ist. Bitte versuche es später noch einmal.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Problem bei der Authentifizierung dieser Instanz aufgetreten. Möglicherweise ist sie von außen nicht erreichbar, um ihre URL zu überprüfen.",
    "Something unexpected happened." : "Es ist etwas Unerwartetes passiert.",
    "The URL is invalid." : "Die URL ist ungültig",
    "An HTTPS URL is required." : "Eine HTTPS-URL ist erforderlich.",
    "The email address is invalid." : "Die E-Mail-Adresse ist ungültig.",
    "The language is invalid." : "Die Sprache ist ungültig.",
    "The country is invalid." : "Das Land ist ungültig.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Es gibt ein Problem mit dem Anfrage für den Trial-Test. Bitte die Protokolldateien für weitere Informationen überprüfen.",
    "Too many requests are send from your servers address. Please try again later." : "Es werden zu viele Anfragen von deiner Serveradresse aus gesendet. Bitte später noch einmal versuchen.",
    "There is already a trial registered for this Nextcloud instance." : "Für diese Nextcloud-Instanz ist bereits eine Trial-Testversion registriert.",
    "Something unexpected happened. Please try again later." : "Es ist etwas Unerwartetes passiert. Bitte später erneut versuchen.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Trial-Test konnte nicht angefordert werden, da der Trial-Testserver sich falsch verhalten hat. Bitte versuche es später noch einmal.",
    "Trial requested but failed to get account information. Please check back later." : "Trial-Testversion angefordert, aber keine Kontoinformationen erhalten. Bitte versuche es später erneut.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Es ist ein Problem bei der Authentifizierung dieser Anfrage aufgetreten. Möglicherweise ist sie von außen nicht erreichbar, um ihre URL zu überprüfen.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Das Abrufen von Kontoinformationen ist fehlgeschlagen, weil sich der Trial-Server falsch verhalten hat. Bitte später noch einmal versuchen.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Beim Abrufen der Kontoinformationen ist ein Problem aufgetreten. Bitte überprüfe deine Protokolldateien für weitere Informationen.",
    "There is no such account registered." : "Ein solches Konto ist nicht registriert.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Kontoinformationen konnten nicht abgerufen werden, da der Trial-Testserver nicht erreichbar ist. Bitte versuche es später erneut.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Fehler beim Löschen des Singnalisierungsserver-Kontos. Bitte versuche es später erneut.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Konto konnte nicht gelöscht werden, da sich der Trial-Testserver falsch verhalten hat. Bitte versuche es später erneut.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Es gibt ein Problem mit dem Löschen des Kontos. Bitte die Protokolldateien für weitere Informationen überprüfen.",
    "Too many requests are sent from your servers address. Please try again later." : "Es wurden zu viele Anfragen von deiner Serveradresse gesendet. Bitte versuche es später noch einmal.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Konto konnte nicht gelöscht werden, da der Trial-Testserver nicht erreichbar ist. Bitte versuche es später erneut.",
    "Note to self" : "Notiz an mich",
    "A place for your private notes, thoughts and ideas" : "Ein Platz für deine privaten Notizen, Gedanken und Ideen",
    "Transcript is AI generated and may contain mistakes" : "Das Transkript wird von KI generiert und kann Fehler enthalten",
    "Summary is AI generated and may contain mistakes" : "Die Zusammenfassung wird von KI generiert und kann Fehler enthalten",
    "Let's get started!" : "Los geht's!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Talk** ist eine sichere, selbst gehostete Kommunikationsplattform, die sich nahtlos in das Nextcloud-Ökosystem integriert.\n\n#### Hauptmerkmale von Nextcloud Talk:\n\n* Chat und Messaging in privaten und Gruppenchats\n* Sprach- und Videoanrufe\n* Dateifreigabe und Integration mit anderen Nextcloud-Apps\n* Anpassbare Gesprächseinstellungen, Moderation und Datenschutzkontrollen\n* Web, Desktop und Mobile (iOS und Android)\n* Private & sichere Kommunikation\n\n Erfahre mehr in der [Benutzerdokumentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Willkommen bei Nextcloud Talk\n\nNextcloud Talk ist eine private und leistungsstarke Messaging-App, die mit Nextcloud integriert ist. Chatte in privaten oder Gruppenunterhaltungen, arbeite über Sprach- und Videoanrufe zusammen, organisiere Webinare und Veranstaltungen, passe deine Unterhaltungen an und vieles mehr.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 Texte formatieren, um aussagekräftige Nachrichten zu erstellen\n\nIn Nextcloud Talk kannst du die Markdown-Syntax verwenden, um deine Nachrichten zu formatieren. Du kannst zum Beispiel **fett** oder *kursiv* formatieren oder `Texte als Code hervorheben`. Du kannst sogar Tabellen erstellen und Überschriften zu deinem Text hinzufügen.\n\nMöchtest du einen Tippfehler korrigieren oder die Formatierung ändern? Bearbeite deine Nachricht, indem du im Nachrichtenmenü auf \"Nachricht bearbeiten\" klickst.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 Anhänge und Links hinzufügen\n\nFüge Dateien aus deinem Nextcloud Hub über die Schaltfläche \"+\" hinzu. Teile Elemente aus Dateien und verschiedenen Nextcloud-Apps. Einige Apps unterstützen sogar interaktive Widgets, z. B. die Text-App.",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 Lass den Unterhaltungen ihren Lauf: Erwähne Nutzer, reagiere auf Nachrichten und mehr\n\nDu kannst alle Teilnehmer einer Unterhaltung mit %s erwähnen oder bestimmte Teilnehmer erwähnen, indem du \"@\" eingibst und ihren Namen aus der Liste auswählst.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Du kannst auf Nachrichten antworten, sie an andere Chats und Personen weiterleiten oder Nachrichteninhalte kopieren.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ Mehr tun mit Smart Picker\n\nGib einfach \"/\" ein oder wähle das Menü \"+\", um den Smart Picker zu öffnen, mit dem du verschiedene Inhalte an deine Nachrichten anhängen kannst. Du kannst den Smart Picker so konfigurieren, dass du Elemente aus Nextcloud-Apps, GIFs, Kartenpositionen, KI-generierte Inhalte und vieles mehr hinzufügen kannst.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ Gesprächseinstellungen verwalten\n\nIm Menü \"Unterhaltung\" kannst du auf verschiedene Einstellungen zur Verwaltung deiner Unterhaltungen zugreifen, wie z. B.:\n* Unterhaltungsinformationen bearbeiten\n* Verwalten von Benachrichtigungen\n* Zahlreiche Moderationsregeln anwenden\n* Zugang und Sicherheit konfigurieren\n* Aktivieren von Bots\n* und mehr!",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Vereinigte Arabische Emirate",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua und Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albanien",
    "Armenia" : "Armenien",
    "Angola" : "Angola",
    "Antarctica" : "Antarktis",
    "Argentina" : "Argentinien",
    "American Samoa" : "Amerikanisch-Samoa",
    "Austria" : "Österreich",
    "Australia" : "Australien",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland Inseln",
    "Azerbaijan" : "Aserbaidschan",
    "Bosnia and Herzegovina" : "Bosnien und Herzegowina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesch",
    "Belgium" : "Belgien",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarien",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunei",
    "Bolivia, Plurinational State of" : "Bolivien",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Saba und Sint Eustatius",
    "Brazil" : "Brasilien",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvetinsel",
    "Botswana" : "Botswana",
    "Belarus" : "Belarus",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kokosinseln",
    "Congo, the Democratic Republic of the" : "Kongo (Demokratische Republik)",
    "Central African Republic" : "Zentralafrikanische Republik",
    "Congo" : "Kongo",
    "Switzerland" : "Schweiz",
    "Côte d'Ivoire" : "Elfenbeinküste",
    "Cook Islands" : "Cookinseln",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "China",
    "Colombia" : "Kolumbien",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kap Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Weihnachtsinsel",
    "Cyprus" : "Zypern",
    "Czechia" : "Tschechien",
    "Germany" : "Deutschland",
    "Djibouti" : "Dschibuti",
    "Denmark" : "Dänemark",
    "Dominica" : "Dominica",
    "Dominican Republic" : "Dominikanische Republik",
    "Algeria" : "Algerien",
    "Ecuador" : "Ekuador",
    "Estonia" : "Estland",
    "Egypt" : "Ägypten",
    "Western Sahara" : "Westsahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanien",
    "Ethiopia" : "Äthiopien",
    "Finland" : "Finnland",
    "Fiji" : "Fidschi",
    "Falkland Islands (Malvinas)" : "Falklandinseln",
    "Micronesia, Federated States of" : "Mikronesien, Föderierte Staaten",
    "Faroe Islands" : "Färöer",
    "France" : "Frankreich",
    "Gabon" : "Gabun",
    "United Kingdom of Great Britain and Northern Ireland" : "Vereinigtes Königreich Großbritannien und Nordirland",
    "Grenada" : "Grenada",
    "Georgia" : "Georgien",
    "French Guiana" : "Französisch-Guinea",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grönland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Äquatorialguinea",
    "Greece" : "Griechenland",
    "South Georgia and the South Sandwich Islands" : "Südgeorgien und die Südlichen Sandwichinseln",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hongkong",
    "Heard Island and McDonald Islands" : "Heard und die McDonaldinseln",
    "Honduras" : "Honduras",
    "Croatia" : "Kroatien",
    "Haiti" : "Haiti",
    "Hungary" : "Ungarn",
    "Indonesia" : "Indonesien",
    "Ireland" : "Irland",
    "Israel" : "Israel",
    "Isle of Man" : "Isle of Man",
    "India" : "Indien",
    "British Indian Ocean Territory" : "Britisches Territorium im Indischen Ozean",
    "Iraq" : "Irak",
    "Iran, Islamic Republic of" : "Iran",
    "Iceland" : "Island",
    "Italy" : "Italien",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordanien",
    "Japan" : "Japan",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirgistan",
    "Cambodia" : "Kambodscha",
    "Kiribati" : "Kiribati",
    "Comoros" : "Komoren",
    "Saint Kitts and Nevis" : "St. Kitts und Nevis",
    "Korea, Democratic People's Republic of" : "Nordkorea",
    "Korea, Republic of" : "Korea, Republik",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Kaimaninseln",
    "Kazakhstan" : "Kasachstan",
    "Lao People's Democratic Republic" : "Laos",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "St. Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litauen",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Lettland",
    "Libya" : "Libyen",
    "Morocco" : "Marokko",
    "Monaco" : "Monaco",
    "Moldova, Republic of" : "Moldawien (Republik)",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "St. Martin",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshallinseln",
    "North Macedonia" : "Nordmazedonien",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolei",
    "Macao" : "Macau",
    "Northern Mariana Islands" : "Nördliche Marianen",
    "Martinique" : "Martinique",
    "Mauritania" : "Mauretanien",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Malediven",
    "Malawi" : "Malawi",
    "Mexico" : "Mexiko",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mosambik",
    "Namibia" : "Namibia",
    "New Caledonia" : "Neukaledonien",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolkinsel",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Niederlande",
    "Norway" : "Norwegen",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Neuseeland",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Französisch-Polynesien",
    "Papua New Guinea" : "Papua-Neuguinea",
    "Philippines" : "Philippinen",
    "Pakistan" : "Pakistan",
    "Poland" : "Polen",
    "Saint Pierre and Miquelon" : "Saint-Pierre und Miquelon",
    "Pitcairn" : "Pitcairninseln",
    "Puerto Rico" : "Puerto Rico",
    "Palestine, State of" : "Palästina",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Rumänien",
    "Serbia" : "Serbien",
    "Russian Federation" : "Russland",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Saudi-Arabien",
    "Solomon Islands" : "Salomonen",
    "Seychelles" : "Seychellen",
    "Sudan" : "Sudan",
    "Sweden" : "Schweden",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "St. Helena, Ascension und Tristan da Cunha",
    "Slovenia" : "Slowenien",
    "Svalbard and Jan Mayen" : "Spitzbergen und Jan Mayen",
    "Slovakia" : "Slowakei",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Südsudan",
    "Sao Tome and Principe" : "São Tomé und Príncipe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten",
    "Syrian Arab Republic" : "Syrien",
    "Eswatini" : "Eswatini",
    "Turks and Caicos Islands" : "Turks- und Caicosinseln",
    "Chad" : "Tschad",
    "French Southern Territories" : "Französische Süd- und Antarktisgebiete",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tadschikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Osttimor",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunesien",
    "Tonga" : "Tonga",
    "Turkey" : "Türkei",
    "Trinidad and Tobago" : "Trinidad und Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taiwan",
    "Tanzania, United Republic of" : "Tansania",
    "Ukraine" : "Ukraine",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "United States Minor Outlying Islands",
    "United States of America" : "Vereinigte Staaten von Amerika",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Usbekistan",
    "Holy See" : "Vatikanstadt",
    "Saint Vincent and the Grenadines" : "St. Vincent und die Grenadinen",
    "Venezuela, Bolivarian Republic of" : "Venezuela",
    "Virgin Islands, British" : "Jungferninseln (britisch)",
    "Virgin Islands, U.S." : "Jungferninseln, U.S.",
    "Viet Nam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis und Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Südafrika",
    "Zambia" : "Sambia",
    "Zimbabwe" : "Simbabwe",
    "Background blur" : "Hintergrund verwischt",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "Es konnte nicht geprüft werden, ob WASM-Ladeunterstützung verfügbar ist. Bitte prüfe manuell, ob dein Webserver `.wasm`-Dateien bereitstellt.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Dein Webserver ist nicht richtig eingerichtet, um `.wasm`-Dateien auszuliefern. Dies ist normalerweise ein Problem mit der Nginx-Konfiguration. Für die Hintergrundunschärfe muss eine Anpassung vorgenommen werden, um auch `.wasm`-Dateien auszuliefern. Vergleiche deine Nginx-Konfiguration mit der empfohlenen Konfiguration in unserer Dokumentation.",
    "Talk configuration values" : "Talk Einstellungswerte",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "Das Erzwingen einer Anrufdauer wird nur mit System-Cron unterstützt. Bitte aktiviere System-Cron oder entferne die Konfiguration `max_call_duration`.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "Kleine `max_call_duration`-Werte (derzeit auf %d) sind aufgrund technischer Beschränkungen nicht durchsetzbar. Die Hintergrundaufgabe wird nur alle 5 Minuten ausgeführt, die Verwendung erfolgt also auf eigene Gefahr.",
    "Federation" : "Federation",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Es wird dringend empfohlen, \"memcache.locking\" einzurichten, wenn Talk-Federation aktiviert ist.",
    "High-performance backend" : "Hochleistungs-Backend",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "Kein Hochleistungs-Backend konfiguriert – Ohne das Hochleistungs-Backend skaliert es nur für kleinere Meetings (max. 2–3 Teilnehmer). Bitte richte das Hochleistungs-Backend ein, um sicherzustellen, dass Meetings mit mehreren Teilnehmern reibungslos funktionieren.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "Die Ausführung des Hochleistungs-Backends im Modus \"conversation_cluster\" ist veraltet und wird in der nächsten Version nicht mehr unterstützt. Das Hochleistungs-Backend unterstützt heutzutage echtes Clustering, das stattdessen verwendet werden sollte.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "Das Definieren mehrerer Hochleistungs-Backends ist veraltet und wird in der nächsten Version nicht mehr unterstützt. Stattdessen sollte ein Load Balancer zusammen mit geclusterten Signalservern eingerichtet und in den Talk-Einstellungen konfiguriert werden.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "Der gespeicherte öffentliche Schlüssel für den verwendeten Algorithmus %1$s stimmt nicht mit dem gespeicherten privaten Schlüssel überein. %2$s ausführen, um das Problem zu beheben.",
    "High-performance backend not configured correctly. Run %s for details." : "Hochleistungs-Backend nicht richtig konfiguriert. Für Einzelheiten %s ausführen.",
    "High-performance backend not configured correctly" : "Hochleistungs-Backend nicht richtig konfiguriert",
    "Error: Cannot connect to server" : "Fehler: Kann nicht zum Server verbinden",
    "Error: Server did not respond with proper JSON" : "Fehler: Server hat nicht mit korrektem JSON geantwortet",
    "Error: Certificate expired" : "Fehler: Zertifikat ist abgelaufen",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Fehler: Die Systemzeiten des Nextcloud-Servers und des Hochleistungs-Backend-Servers sind nicht synchron. Bitte stelle sicher, dass beide Server mit einem Zeitserver verbunden sind oder synchronisiere ihre Zeit manuell.",
    "Could not get version" : "Version kann nicht abgerufen werden",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Fehler: Aktuelle Version: {version}; Server muss aktualisiert werden, um mit dieser Version von Talk kompatibel zu sein",
    "Error: Server responded with: {error}" : "Fehler: Der Server antwortete mit: {error}",
    "Error: Unknown error occurred" : "Fehler: Ein unbekannter Fehler ist aufgetreten",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Achtung: Laufende Version: {version}; Der Server unterstützt nicht alle Funktionen dieser Talk-Version, fehlende Funktionen: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "Es wird dringend empfohlen, einen Speichercache zu konfigurieren, wenn Nextcloud Talk mit einem Hochleistungs-Backend ausgeführt wird.",
    "Client Push" : "Client-Push",
    "Client Push is installed, this improves the punctuality of Talk notifications." : "Client Push ist installiert, dies verbessert die Rechtzeitigkeit von Talk-Benachrichtigungen.",
    "{notify_push} is not installed. This may lead to delayed Talk notifications." : "{notify_push} ist nicht installiert. Dies kann zu verzögerten Talk-Benachrichtigungen führen.",
    "Recording backend" : "Aufzeichnungs-Backend",
    "Using the recording backend requires a High-performance backend." : "Die Verwendung des Aufzeichnungs-Backends erfordert ein Hochleistungs-Backend.",
    "No recording backend configured" : "Kein Aufzeichnungs-Backend konfiguriert",
    "SIP configuration" : "SIP-Konfiguration",
    "Using the SIP functionality requires a High-performance backend." : "Die Nutzung der SIP-Funktionalität erfordert ein Hochleistungs-Backend.",
    "Assigned Talk phone numbers must not start with + or 0. Please remove or update the following numbers:\n{list}" : "Zugewiesene Talk-Telefonnummern dürfen nicht mit + oder 0 beginnen. Bitte die folgenden Nummern entfernen oder aktualisieren:\n{list}",
    "No SIP backend configured" : "Kein SIP-Backend konfiguriert",
    "Invalid date, date format must be YYYY-MM-DD" : "Ungültiges Datum, Zulässiges Datumsformat: JJJJ-MM-TT",
    "Conversation not found" : "Unterhaltung nicht gefunden",
    "Path is already shared with this conversation" : "Der Pfad wurde bereits mit dieser Unterhaltung geteilt",
    "Chat, video & audio-conferencing using WebRTC" : "Chat, Video & Audio-Konferenzen mittels WebRTC",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Chat, Video- und Audiokonferenzen mit WebRTC\n\n* 💬 **Chat** Nextcloud Talk verfügt über einen einfachen Text-Chat, in dem du Dateien über deine Nextcloud Dateien-App oder dein lokales Gerät teilen oder hochladen und andere Teilnehmende erwähnen kannst.\n* 👥 **Private, Gruppen-, öffentliche und passwortgeschützte Anrufe!** Lade jemanden oder eine ganze Gruppe ein oder sende einen öffentlichen Link, um zu einem Anruf einzuladen.\n* 🌐 **Federierte Chats** Chatte mit anderen Nextcloud-Benutzern über deren Server\n* 💻 **Bildschirmfreigabe!** Teile deinen Bildschirm mit den Teilnehmern deiner Unterhaltung.\n* 🚀 **Integration mit anderen Nextcloud-Apps** wie Dateien, Kalender, Benutzerstatus, Dashboard, Flow, Karten, Smart Picker, Kontakte, Deck und viele mehr.\n* 🌉 **Mit anderen Chat-Lösungen synchronisieren** Durch die Integration von [Matterbridge](https://github.com/42wim/matterbridge/) in Talk kannst du viele andere Chat-Lösungen ganz einfach mit Nextcloud Talk und umgekehrt synchronisieren.",
    "Leave call" : "Anruf verlassen",
    "Navigating away from the page will leave the call in {conversation}" : "Bei verlassen der Seite, wird der Anruf in {conversation} beendet",
    "Stay in call" : "Beim Anruf bleiben",
    "Error occurred when getting the conversation information" : "Fehler beim Abrufen der Unterhaltungsinformationen ",
    "Duplicate session" : "Doppelte Sitzung",
    "Discuss this file" : "Diese Datei besprechen",
    "Loading …" : "Lade …",
    "Share this file with others to discuss it" : "Teile diese Datei, um sie mit anderen zu besprechen",
    "Join conversation" : "Unterhaltung beitreten",
    "Share this file" : "Diese Datei teilen",
    "Error occurred when joining the conversation" : "Es ist ein Fehler beim Beitritt zur Unterhaltung aufgetreten.",
    "Open in full application" : "In der Desktopversion öffnen",
    "This conversation is password-protected." : "Diese Unterhaltung ist passwortgeschützt.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Es wurden mehrere ungültige Passworteingaben von deiner IP-Adresse festgestellt. Daher wird die nächste Anmeldung um 30 Sekunden verzögert.",
    "The password is wrong. Try again." : "Das Passwort ist falsch. Bitte erneut versuchen.",
    "Password" : "Passwort",
    "Submit" : "Übermitteln",
    "Error requesting the password." : "Fehler bei der Passwortanforderung",
    "Request password" : "Passwort anfordern",
    "This conversation has ended" : "Diese Unterhaltung wurde beendet",
    "Close Talk sidebar" : "Talk-Seitenleiste schließen",
    "Open Talk sidebar" : "Talk-Seitenleiste öffnen",
    "Everyone" : "Jeder",
    "Users and moderators" : "Benutzer und Moderatoren",
    "Moderators only" : "Nur Moderatoren",
    "Disable calls" : "Anrufe deaktivieren",
    "Save changes" : "Änderungen speichern",
    "Saving …" : "Speichern …",
    "Saved!" : "Gespeichert!",
    "Limit to groups" : "Auf Gruppen beschränken",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Wenn mindestens eine Gruppe ausgewählt ist, so können nur Personen von den aufgelisteten Gruppen an den Unterhaltungen teilnehmen.",
    "Guests can still join public conversations." : "Gäste können nach wie vor öffentlichen Unterhaltungen beitreten.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Benutzer, welche Talk nicht mehr nutzen können, werden weiterhin als Teilnehmer ihrer früheren Unterhaltungen aufgelistet. Chatnachrichten werden ebenfalls aufbewahrt.",
    "Limit using Talk" : "Beschränkung bei der Nutzung von Talk",
    "Limit creating a public and group conversation" : "Beschränkung für das Erstellen von öffentlichen und Gruppenunterhaltungen",
    "Limit creating conversations" : "Beschränkung beim Erstellen von Unterhaltungen",
    "Limit starting a call" : "Starten von Anrufen begrenzen",
    "Limit starting calls" : "Beschränkung beim Anrufaufbau",
    "When a call has started, everyone with access to the conversation can join the call." : "Nachdem eine Unterhaltung gestartet wurde, kann jeder, der Zugriff auf die Unterhaltung hat, dieser beitreten",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Die folgenden Bots sind auf diesem Server installiert. In der Dokumentation findest du Einzelheiten zum {linkstart1}Erstellen deines eigenen Bots{linkend} oder einer {linkstart2}Liste von Bots{linkend}, die du auf deinem Server aktivieren kannst.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Auf diesem Server sind keine Bots installiert. In der Dokumentation findest du Einzelheiten zum {linkstart1}Erstellen deines eigenen Bots{linkend} oder einer {linkstart2}Liste von Bots{linkend}, die du auf deinem Server aktivieren kannst.",
    "Description is not provided" : "Keine Beschreibung vorhanden",
    "Locked for moderators" : "Gesperrt für Moderatoren",
    "Enabled" : "Aktiviert",
    "Disabled" : "Deaktiviert",
    "Bots settings" : "Bots-Einstellungen",
    "State" : "Status",
    "Name" : "Name",
    "Last error" : "Letzter Fehler",
    "Total errors count" : "Gesamtzahl an Fehlern",
    "Find more bots" : "Weitere Bots finden",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "Vertrauenswürdige Server können auf der {linkstart}Einstellungsseite für Freigaben{linkend} konfiguriert werden.",
    "Beta" : "Beta",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "Federated Chats und Anrufe funktionieren bereits. Die Verwaltung von Anhängen ist für eine spätere Version geplant.",
    "Enable Federation in Talk app" : "Federation in der Talk-App aktivieren",
    "Permissions" : "Berechtigungen",
    "Allow users to be invited to federated conversations" : "Benutzern erlauben, zu federierten Unterhaltungen eingeladen zu werden.",
    "Allow users to invite federated users into conversation" : "Benutzern erlauben, federierte Benutzer zu Unterhaltungen einzuladen.",
    "Only allow to federate with trusted servers" : "Nur erlauben, mit vertrauenswürdigen Servern zu federieren",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "Wenn mindestens eine Gruppe ausgewählt ist, können nur Personen der aufgelisteten Gruppen federierte Benutzer zu Unterhaltungen einladen.",
    "Groups allowed to invite federated users" : "Gruppen, die berechtigt sind, federierte Konten einzuladen",
    "Select groups …" : "Gruppen auswählen …",
    "All messages" : "Alle Nachrichten",
    "@-mentions only" : "Nur @-Erwähnungen",
    "Off" : "Aus",
    "General settings" : "Allgemeine Einstellungen",
    "Default notification settings" : "Standard Benachrichtigungseinstellungen",
    "Default group notification" : "Standard Gruppenbenachrichtigung",
    "Default group notification for new groups" : "Standard Gruppenbenachrichtigung für neue Gruppen",
    "Integration into other apps" : "Einbindung in andere Apps",
    "Allow conversations on files" : "Alle Unterhaltungen zu Dateien",
    "Allow conversations on public shares for files" : "Alle Unterhaltungen in öffentlichen Freigaben zu Dateien",
    "End-to-end encrypted calls" : "Ende-zu-Ende-verschlüsselte Anrufe",
    "Enable encryption" : "Verschlüsselung aktivieren",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "Für Ende-zu-Ende-verschlüsselte Anrufe mit einer konfigurierten SIP-Brücke ist eine neuere Version des Hochleistungs-Backends und der SIP-Bridge erforderlich.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "Mobile Clients unterstützen derzeit Ende-zu-Ende-verschlüsselte Anrufe nicht.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Durch Anklicken des obigen Buttons werden die Angaben im Formular an die Server der Struktur AG geschickt. Weitere Informationen hierzu gibt es unter {linkstart}spreed.eu{linkend}.",
    "Pending" : "Ausstehend",
    "Error" : "Fehler",
    "Blocked" : "Blockiert",
    "Active" : "Aktiv",
    "Expired" : "Abgelaufen",
    "Never" : "Niemals",
    "The trial could not be requested. Please try again later." : "Der Test konnte nicht angefordert werden. Bitte versuche es später noch einmal.",
    "The account could not be deleted. Please try again later." : "Konto konnte nicht gelöscht werden. Bitte später erneut versuchen.",
    "Hosted High-performance backend" : "Gehostetes Hochleistungs-Backend",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Unser Partner Struktur AG bietet einen Dienst an, bei dem ein gehosteter Signalisierungsserver angefordert werden kann. Dazu brauchst du nur das untenstehende Formular auszufüllen und deine Nextcloud wird ihn anfordern. Sobald der Server für dich eingerichtet ist, werden die Anmeldedaten automatisch ausgefüllt. Dadurch werden die bestehenden Einstellungen des Signalisierungsservers überschrieben.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Wenn dein Hochleistungs-Backend-Konto STUN- und/oder TURN-Funktionen enthält, werden die Einstellungen entsprechend aktualisiert.",
    "URL of this Nextcloud instance" : "URL dieser Nextcloud-Installation",
    "Full name of the user requesting the trial" : "Vollständiger Name des Benutzers, der die Testversion anfordert",
    "Email of the user" : "E-Mail-Adresse des Benutzers",
    "Language" : "Sprache",
    "Country" : "Land",
    "Request signaling server trial" : "Testversion des Signalisierungsservers anfordern",
    "You can see the current status of your hosted signaling server in the following table." : "Den aktuellen Status deines gehosteten Signalisierungsservers siehst du in der folgenden Tabelle.",
    "Status" : "Status",
    "Created at" : "Erstellt am",
    "Expires at" : "Läuft ab am",
    "Limits" : "Beschränkungen",
    "STUN included" : "STUN inklusive",
    "Yes" : "Ja",
    "No" : "Nein",
    "TURN included" : "TURN inklusive",
    "Delete the signaling server account" : "Signalisierungsserver-Konto löschen",
    "_%n user_::_%n users_" : ["%n Benutzer","%n Benutzer"],
    "Installed version: {version}" : "Installierte Version: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Du kannst Matterbridge installieren, um Nextcloud Talk mit einigen anderen Diensten zu verlinken. Besuche deren {linkstart1}GitHub-Seite{linkend} für weitere Details. Das Herunterladen und Installieren der App kann eine Weile dauern. Falls die Zeit überschritten wird, installiere sie bitte manuell über den {linkstart2}Nextcloud App Store{linkend}.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "Die Matterbridge-Binärdatei hat falsche Berechtigungen. Bitte sicher stellen, dass die Matterbridge-Binärdatei dem richtigen Benutzer gehört und ausgeführt werden kann. Sie befindet sich unter \"/.../nextcloud/apps/talk_matterbridge/bin/\".",
    "Matterbridge binary was not found or couldn't be executed." : "Die Matterbridge Anwendung konnte nicht gefunden werden oder konnte nicht ausgeführt werden.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Du kannst den Pfad zur Matterbridge-Binärdatei auch manuell über die Konfiguration festlegen. Weitere Informationen findest du in der {linkstart} Matterbridge-Integrationsdokumentation {linkend}.",
    "Downloading …" : "Herunterladen …",
    "Install Talk Matterbridge" : "Talk-Matterbridge installieren",
    "An error occurred while installing the Matterbridge app" : "Es ist ein Fehler bei der Installation der Matterbridge-App aufgetreten.",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Es ist ein Fehler bei der Installation von Talk Matterbridge aufgetreten. Bitte installiere es manuell.",
    "Failed to execute Matterbridge binary." : "Matterbridge-Binärdatei konnte nicht ausgeführt werden.",
    "Matterbridge integration" : "Matterbridge-Einbindung",
    "Enable Matterbridge integration" : "Matterbridge-Einbindung aktivieren",
    "Status: Checking connection" : "Status: Prüfe die Verbindung",
    "OK: Running version: {version}" : "OK: Laufende Version: {version}",
    "Error: Server seems to be a Signaling server" : "Fehler: Der Server scheint ein Signalisierungsserver zu sein",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Fehler: Die Systemzeiten des Nextcloud-Servers und des Aufnahme-Backend-Servers sind nicht synchron. Bitte sicherstellen, dass beide Server mit einem Zeitserver verbunden sind oder synchronisiere die Zeit manuell.",
    "Recording backend URL" : "URL für Aufzeichnungs-Backend",
    "Validate SSL certificate" : "SSL-Zertifikat überprüfen",
    "Delete this server" : "Diesen Server löschen",
    "Test this server" : "Diesen Server testen",
    "Disabled for all calls" : "Für alle Anrufe deaktiviert",
    "Enabled for all calls" : "Für alle Anrufe aktiviert",
    "Configurable on conversation level by moderators" : "Konfigurierbar auf Unterhaltungsebene durch Moderatoren",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "Die PHP-Einstellungen \"upload_max_filesize\" oder \"post_max_size\" erlauben nur das Hochladen von Dateien bis zu {maxUpload}.",
    "Recording backend settings saved" : "Aufzeichnungs-Backend Einstellungen gespeichert",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "Moderatoren können die Zustimmung auf Unterhaltungsebene aktivieren. Die Einwilligung zur Aufzeichnung ist für jeden Teilnehmer vor der Teilnahme an der Unterhaltung erforderlich.",
    "The consent to be recorded will be required for each participant before joining every call." : "Vor der Teilnahme an einer Unterhaltung ist für jeden Teilnehmer die Einwilligung zur Aufzeichnung erforderlich.",
    "The consent to be recorded is not required." : "Eine Einwilligung zur Aufzeichnung ist nicht erforderlich.",
    "Recording backend configuration is only possible with a High-performance backend." : "Aufzeichnungs-Backend-Einrichtung ist nur in Verbindung mit einem Hochleistungs-Backend möglich.",
    "Add a new recording backend server" : "Einen neuen Aufzeichnungs-Backend-Server hinzufügen",
    "Shared secret" : "Gemeinsames Geheimnis",
    "Recording consent" : "Zustimmung zur Aufzeichnung",
    "Recording transcription" : "Aufnahme-Transskription",
    "Automatically transcribe call recordings with a transcription provider" : "Automatisches Transkribieren von Gesprächsaufzeichnungen mit einem Transkriptionsanbieter",
    "Automatically summarize call recordings with transcription and summary providers" : "Automatisches Zusammenfassen von Anrufaufzeichnungen mit Transkriptions- und Zusammenfassungsanbietern",
    "SIP configuration saved!" : "SIP-Konfiguration gespeichert!",
    "SIP configuration is only possible with a High-performance backend." : "SIP-Einrichtung ist nur in Verbindung mit einem Hochleistungs-Backend möglich.",
    "Enable SIP Dial-out option" : "SIP-Anrufen-Option aktivieren",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "Der Signalisierungsserver muss auf die unterstützte SIP-Anrufen-Funktion aktualisiert werden.",
    "Do not show SIP Dial-out caller number" : "Abgehend die eigene Rufnummer nicht anzeigen",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "Die anonyme Nummer sollte als \"unbekannte\" oder \"unterdrückte Nummer\" angezeigt werden, um den Empfänger anzurufen",
    "Dial-out number" : "Ausgehende Telefonnummer",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "E164-formatierte Nummer, die als Fallback-Rufnummer für ausgehende Anrufe verwendet wird",
    "Dial-out prefix" : "Vorwahl für ausgehende Anrufe",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "Präfix zur eingestellten Rufnummer für ausgehende Anrufe (Standard ist `+`)",
    "Restrict SIP configuration" : "SIP-Konfiguration einschränken",
    "Enable SIP configuration" : "SIP-Konfiguration aktivieren",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Nur Benutzer der folgenden Gruppen können SIP in von ihnen moderierten Unterhaltungen aktivieren",
    "Phone number (Country)" : "Telefonnummer (Land)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Diese Informationen werden sowohl in Einladungs-E-Mails versandt als auch in der Seitenleiste für alle Teilnehmer angezeigt.",
    "Nextcloud base URL" : "Nextcloud-Basis-URL",
    "Talk Backend URL" : "Talk-Backend-URL",
    "WebSocket URL" : "WebSocket-URL",
    "Available features" : "Verfügbare Funktionen",
    "Error: Websocket connection failed" : "Fehler: Websocket-Verbindung fehlgeschlagen",
    "Error code" : "Fehlercode",
    "Error message" : "Fehlermeldung",
    "Error: Websocket connection failed. Check browser console" : "Fehler: Websocket-Verbindung fehlgeschlagen. Browser-Konsole überprüfen",
    "High-performance backend URL" : "Hochleistungs-Backend-URL",
    "Missing High-performance backend warning hidden" : "Warnung zu fehlendem Hochleistungs-Backend ausgeblendet",
    "High-performance backend settings saved" : "Hochleistungs-Backend Einstellungen gespeichert",
    "Nextcloud Talk setup not complete" : "Einrichtung von Nextcloud Talk nicht abgeschlossen",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Bitte beachten, dass bei Meetings mit mehr als 2 Teilnehmern ohne das Hochleistungs-Backend höchstwahrscheinlich Verbindungsprobleme auftreten und die teilnehmenden Geräte stark belastet werden.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Das Hochleistungs-Backend installieren, um sicherzustellen, dass Meetings mit mehreren Teilnehmern reibungslos funktionieren.",
    "Nextcloud portal" : "Nextcloud Portal",
    "Quick installation guide" : "Kurzanleitung zur Installation",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "Das Hochleistungs-Backend ist für Anrufe und Unterhaltungen mit mehreren Teilnehmern erforderlich. Ohne das Backend müssen alle Teilnehmer ihr eigenes Video für jeden anderen Teilnehmer einzeln hochladen, was höchstwahrscheinlich zu Verbindungsproblemen und einer hohen Belastung der teilnehmenden Geräte führt.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "Es wird dringend empfohlen, einen verteilten Cache einzurichten, wenn du Nextcloud Talk mit einem Hochleistungs-Backend verwendest.",
    "Add High-performance backend server" : "Hochleistungs-Backend-Server hinzufügen",
    "Warn about connectivity issues in calls with more than 2 participants" : "Vor Verbindungsproblemen bei Anrufen mit mehr als 2 Teilnehmern warnen",
    "STUN server URL" : "STUN-Server-URL",
    "The server address is invalid" : "Die Serveradresse ist ungültig.",
    "STUN settings saved" : "STUN-Einstellungen gespeichert",
    "STUN servers" : "STUN-Server",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Der STUN-Server wird verwendet, um die öffentliche IP-Adresse von Teilnehmern hinter einem Router zu bestimmen.",
    "Add a new STUN server" : "Einen neuen STUN-Server hinzufügen",
    "{schema} scheme must be used with a domain" : "{schema}-Schema muss mit einer Domain verwendet werden",
    "{option1} and {option2}" : "{option1} und {option2}",
    "{option} only" : "nur {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "OK: ICE-Kandidaten erfolgreich durch den TURN-Server zurück gesendet",
    "Error: No working ICE candidates returned by the TURN server" : "Fehler: Keine funktionierenden ICE-Kandidaten durch den TURN-Server zurück gesendet",
    "Testing whether the TURN server returns ICE candidates" : "Testen, ob der TURN-Server ICE-Kandidaten zurückgibt",
    "TURN server schemes" : "TURN-Server-Schemata",
    "TURN server URL" : "TURN-Server-URL",
    "TURN server secret" : "TURN-Server-Secret",
    "TURN server protocols" : "TURN-Serverprotokolle",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "Ein TURN-Server wird verwendet, um den Datenverkehr von Teilnehmern hinter einer Firewall zu übertragen. Wenn einzelne Teilnehmer keine Verbindung zu anderen herstellen können, ist höchstwahrscheinlich ein TURN-Server erforderlich. Anweisungen zum Einrichten sind in folgender {linkstart}Dokumentation{linkend} zu finden.",
    "TURN settings saved" : "TURN-Einstellungen gespeichert",
    "TURN servers" : "TURN-Server",
    "Add a new TURN server" : "Einen neuen TURN-Server hinzufügen",
    "Failed" : "Fehlgeschlagen",
    "OK" : "OK",
    "Checking …" : "Überprüfe …",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Fehlgeschlagen: WebAssembly ist in diesem Browser deaktiviert oder wird nicht unterstützt. Bitte aktiviere WebAssembly oder verwende einen Browser, der es unterstützt, um die Prüfung durchzuführen.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Fehlgeschlagen: Die Dateien \".wasm\" und \".tflite\" wurden vom Webserver nicht korrekt zurückgegeben. Bitte prüfe den Abschnitt \"Systemanforderungen\" in der Talk-Dokumentation.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK: \".wasm\"- und \".tflite\"-Dateien wurden ordnungsgemäß vom Webserver zurückgegeben.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Es scheint, dass die PHP- und Apache-Konfiguration nicht kompatibel ist. Bitte beachte, dass PHP nur mit dem Modul MPM_PREFORK und PHP-FPM nur mit dem Modul MPM_EVENT verwendet werden kann.",
    "Web server setup checks" : "Prüfungen der Einrichtung des Webservers",
    "Files required for virtual background can be loaded" : "Die für den virtuellen Hintergrund erforderlichen Dateien können geladen werden",
    "Federated user" : "Federated-Benutzer",
    "Assign participants to rooms" : "Teilnehmer Räumen zuweisen",
    "Configure breakout rooms" : "Einstellungen für Breakout-Räume",
    "Number of breakout rooms" : "Anzahl an Breakout-Räumen",
    "You can create from 1 to 20 breakout rooms." : "Es können zwischen 1 bis 20 Gruppenräume erstellt werden.",
    "Assignment method" : "Zuweisungsmethode",
    "Automatically assign participants" : "Automatisch hinzugefügte Teilnehmer",
    "Manually assign participants" : "Teilnehmer manuell zuordnen",
    "Allow participants to choose" : "Teilnehmern die Wahl lassen",
    "Create rooms" : "Räume erstellen",
    "Confirm" : "Bestätigen",
    "Create breakout rooms" : "Breakout-Räume erstellen",
    "Reset" : "Zurücksetzen",
    "Delete breakout rooms" : "Breakout-Räume löschen",
    "Room {roomNumber}" : "Raum {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Aktuelle Breakout-Räume und deren Einstellungen gehen verloren",
    "Cancel" : "Abbrechen",
    "Unassigned participants" : "Nicht zugewiesene Teilnehmer",
    "Back" : "Zurück",
    "Assign" : "Zuweisen",
    "Add participant \"{user}\"" : "Teilnehmer \"{user}\" hinzufügen",
    "Now" : "Jetzt",
    "Invalid calendar selected" : "Ungültiger Kalender ausgewählt",
    "Invalid start time selected" : "Ungültige Startzeit ausgewählt",
    "Invalid end time selected" : "Ungültige Endzeit ausgewählt",
    "Unknown error occurred" : "Unbekannter Fehler aufgetreten",
    "Sending no invitations" : "Keine Einladungen versenden",
    "{participant0} will receive an invitation" : "{participant0} erhält eine Einladung",
    "{participant0} and {participant1} will receive invitations" : "{participant0} und {participant1} erhalten Einladungen",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} und %n weiterer erhalten Einladungen","{participant0}, {participant1} und %n andere erhalten Einladungen"],
    "Invite {user}" : "{user} einladen ",
    "Invite all users and emails in this conversation" : "Alle Benutzer und E-Mail-Adressen in der Unterhaltung einladen",
    "Meeting created" : "Besprechung erstellt",
    "Upcoming meetings" : "Anstehende Besprechungen",
    "No upcoming meetings" : "Keine anstehenden Besprechungen",
    "Schedule a meeting" : "Eine Besprechung planen",
    "Meeting title" : "Titel der Besprechung",
    "From" : "Von",
    "To" : "An",
    "Calendar" : "Kalender",
    "Attendees" : "Teilnehmende",
    "No other participants to send invitations to." : "Keine anderen Teilnehmer, an die Einladungen gesendet werden können.",
    "Add attendees" : "Teilnehmer hinzufügen",
    "Save" : "Speichern",
    "Search participants" : "Suche Teilnehmer",
    "No results" : "Keine Ergebnisse",
    "Done" : "Erledigt",
    "Disable live transcription" : "Live-Transkription deaktivieren",
    "Enable live transcription (generated by AI)" : "Live-Transkription aktivieren (KI-generiert)",
    "Enable live transcription (Live transcriptions app is not installed)" : "Live-Transkription aktivieren (Live-Transkriptions-App ist nicht installiert)",
    "Disable live translation" : "Live-Übersetzung deaktivieren",
    "Enable live translation (generated by AI)" : "Live-Übersetzung aktivieren (KI-generiert)",
    "Original language" : "Ausgangssprache",
    "Live translations app is not installed" : "Die Live-Übersetzungs-App ist nicht installiert",
    "Original language: {languageName}" : "Originalsprache: {languageName}",
    "Translated language" : "Übersetzte Sprache",
    "Translated language: {languageName}" : "Übersetzte Sprache: {languageName}",
    "Exit full screen (F)" : "Vollbild verlassen (F)",
    "Full screen (F)" : "Vollbild (F)",
    "Speaker view" : "Sprecheransicht",
    "Grid view" : "Kachelansicht",
    "Error when trying to load the available live transcription languages" : "Fehler beim Versuch, die verfügbaren Live-Transkriptionssprachen zu laden",
    "Failed to enable live transcription" : "Live-Transkription konnte nicht aktiviert werden",
    "Failed to enable live translations" : "Live-Übersetzung konnten nicht aktiviert werden",
    "Failed to disable live translations" : "Live-Übersetzung konnten nicht deaktiviert werden",
    "Recording consent is required" : "Zustimmung zur Aufzeichnung ist erforderlich",
    "This conversation is read-only" : "Diese Unterhaltung ist schreibgeschützt",
    "Conversation not found or not joined" : "Unterhaltung nicht gefunden oder nicht beigetreten",
    "Lobby is still active and you're not a moderator" : "Die Lobby ist weiterhin aktiv und du bist kein Moderator",
    "Connection failed" : "Verbindung fehlgeschlagen",
    "Reload" : "Neu laden",
    "{nickName} raised their hand." : "{nickName} hat die Hand gehoben.",
    "A participant raised their hand." : "Ein Teilnehmer hat die Hand gehoben",
    "Collapse stripe" : "Streifen einklappen",
    "Expand stripe" : "Streifen aufklappen",
    "Previous page of videos" : "Vorherige Seite mit Videos",
    "Next page of videos" : "Nächste Seite mit Videos",
    "Connecting …" : "Verbinde …",
    "Calling …" : "Rufe an …",
    "Waiting for {user} to join the call" : "Warte darauf, dass  {user} der Unterhaltung beitritt",
    "Waiting for others to join the call …" : "Warte auf weitere Teilnehmer …",
    "You can invite others in the participant tab of the sidebar" : "Du kannst andere Teilnehmer auf dem Teilnehmer-Tab der Seitenleiste einladen",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Du kannst andere Teilnehmer auf dem Teilnehmer-Tab der Seitenleiste oder über diesen Link einladen!",
    "Share this link to invite others!" : "Teile diesen Link, um andere Personen einzuladen!",
    "Copy link" : "Link kopieren",
    "You are not allowed to enable audio" : "Du bist nicht berechtigt, Audio zu aktivieren",
    "No audio. Click to select device" : "Kein Ton. Zum Auswählen des Geräts anklicken",
    "Mute audio" : "Mikrofon stummschalten",
    "Mute audio (M)" : "Mikrofon stummschalten (M)",
    "Unmute audio" : "Mikrofon einschalten",
    "Unmute audio (M)" : "Mikrofon einschalten (M)",
    "None" : "Keine",
    "Select a microphone" : "Ein Mikrofon auswählen",
    "Select a speaker" : "Einen Lautsprecher auswählen",
    "Microphone settings" : "Mikrofoneinstellungen",
    "Check devices" : "Geräte prüfen",
    "Access to camera was denied" : "Zugriff auf die Kamera wurde verweigert",
    "Error while accessing camera: It is likely in use by another program" : "Fehler beim Zugriff auf die Kamera: Sie wird wahrscheinlich von einem anderen Programm verwendet",
    "Error while accessing camera" : "Fehler beim Zugriff auf die Kamera",
    "You have been muted by a moderator" : "Du wurdest von einem Moderator stummgeschaltet",
    "Hide presenter video" : "Moderationsvideo ausblenden",
    "You are not allowed to enable video" : "Du bist nicht berechtigt, Video zu aktivieren",
    "No video. Click to select device" : "Kein Bild. Zum Auswählen des Geräts anklicken",
    "Disable video" : "Video deaktivieren",
    "Disable video (V)" : "Video deaktivieren (V)",
    "Enable video" : "Video aktivieren",
    "Enable video (V)" : "Video aktivieren (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Video aktivieren. Deine Verbindung wird kurz unterbrochen, wenn du Video zum ersten Mal aktivierst.",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Video aktivieren (V) - deine Verbindung wird kurz unterbrochen, wenn du Video zum ersten Mal aktivierst",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Video aktivieren. Deine Verbindung wird kurz unterbrochen, wenn du Video zum ersten Mal aktivierst.",
    "Select a video device" : "Eine Videoquelle auswählen",
    "Show presenter" : "Präsentierenden anzeigen",
    "You" : "Du",
    "Mute" : "Stummschalten",
    "Muted" : "Stummgeschaltet",
    "Show screen" : "Bildschirm anzeigen",
    "Stop following" : "Nicht mehr folgen",
    "Connection could not be established …" : "Es konnte keine Verbindung hergestellt werden …",
    "Connection was lost and could not be re-established …" : "Die Verbindung wurde unterbrochen und konnte nicht wiederhergestellt werden …",
    "Connection could not be established. Trying again …" : "Es konnte keine Verbindung hergestellt werden. Versuche es erneut …",
    "Connection lost. Trying to reconnect …" : "Verbindung zum Server verloren. Es wird versucht diese wiederherzustellen …",
    "Connection problems …" : "Verbindungsprobleme …",
    "Collapse" : "Zuklappen",
    "Expand" : "Erweitern",
    "You need to be logged in to upload files" : "Du musst angemeldet sein, um Dateien hochzuladen",
    "Drop your files to upload" : "Dateien zum Hochladen hineinziehen",
    "Conversation messages" : "Unterhaltungsnachrichten",
    "Scroll to bottom" : "Nach unten blättern",
    "Post message" : "Nachricht senden",
    "Federated conversation" : "Federierte Unterhaltung",
    "Public conversation" : "Öffentliche Unterhaltung",
    "Favorite" : "Favorit",
    "Banned users" : "Gesperrte Personen",
    "Manage the list of banned users in this conversation." : "Liste der in dieser Unterhaltung gesperrten Personen bearbeiten",
    "Manage bans" : "Sperrungen bearbeiten",
    "No banned users" : "Keine gesperrten Personen",
    "Banned by:" : "Ausgeschlossen von:",
    "Date:" : "Datum:",
    "Note:" : "Bemerkung:",
    "Hide details" : "Details ausblenden",
    "Show details" : "Details anzeigen",
    "Unban" : "Entsperren",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "Den Titel und die Beschreibung können Sie im {linkstart} Kalender ↗{linkend} ändern.",
    "Error while updating conversation name" : "Fehler bei der Aktualisierung des Namens der Unterhaltung",
    "Error while updating conversation description" : "Fehler bei der Aktualisierung der Beschreibung der Unterhaltung",
    "Enter a name for this conversation" : "Gib einen Namen für diese Unterhaltung ein.",
    "Edit conversation name" : "Name der Unterhaltung bearbeiten",
    "Edit conversation description" : "Beschreibung der Unterhaltung bearbeiten",
    "Enter a description for this conversation" : "Beschreibung zur Unterhaltung eingeben",
    "Picture" : "Bild",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "Die folgenden Bots können in dieser Unterhaltung aktiviert werden. Wenden dich an deine Administration, um weitere Bots auf diesem Server installieren zu lassen.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "Auf diesem Server sind keine Bots installiert. Wende dich an die Administration, um Bots auf diesem Server installieren zu lassen.",
    "Disable" : "Deaktivieren",
    "Enable" : "Aktivieren",
    "The bot is not available anymore" : "Der Bot ist nicht mehr verfügbar",
    "Breakout rooms" : "Breakout-Räume",
    "Manage breakout rooms" : "Gruppenräume verwalten",
    "Set up breakout rooms for this conversation" : "Gruppenräume für diese Unterhaltung einrichten",
    "Please select a valid PNG or JPG file" : "Bitte eine gültige PNG- oder JPG-Datei wählen",
    "Choose your conversation picture" : "Dein Unterhaltungsbild auswählen",
    "Choose" : "Auswählen",
    "Error setting conversation picture" : "Fehler beim Setzen des Unterhaltungsbildes",
    "Could not set the conversation picture: {error}" : "Unterhaltungsbild konnte nicht festgelegt werden: {error}",
    "Error cropping conversation picture" : "Fehler beim Beschneiden des Unterhaltungsbildes",
    "Error removing conversation picture" : "Fehler beim Entfernen des Unterhaltungsbildes",
    "Set emoji as conversation picture" : "Emoji als Unterhaltungsbild setzen",
    "Set background color for conversation picture" : "Hintergrundfarbe für Unterhaltungsbild setzen",
    "Upload conversation picture" : "Unterhaltungsbild hochladen",
    "Choose conversation picture from files" : "Unterhaltungsbild aus Dateien wählen",
    "Remove conversation picture" : "Unterhaltungsbild entfernen",
    "The file must be a PNG or JPG" : "Die Datei muss im PNG- oder JPG-Format sein",
    "Set picture" : "Bild festlegen",
    "Default permissions modified for {conversationName}" : "Standardberechtigungen für {conversationName} geändert",
    "Could not modify default permissions for {conversationName}" : "Für {conversationName} konnten die Standardberechtigungen nicht geändert werden",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Bearbeite die Standardberechtigungen für die Teilnehmer dieser Unterhaltung. Diese Einstellungen wirken sich nicht auf Moderatoren aus.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Jedes Mal, wenn Berechtigungen in diesem Abschnitt geändert werden, gehen benutzerdefinierte Berechtigungen, die zuvor einzelnen Teilnehmern zugewiesen wurden, verloren.",
    "All permissions" : "Alle Berechtigungen",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Die Teilnehmer haben die Berechtigung einen Anruf zu starten, einem Anruf beizutreten und Audio-, Video- und Bildschirmübertragung zu aktivieren.",
    "Participants can use all available features." : "Teilnehmer können alle verfügbaren Funktionen nutzen.",
    "Restricted" : "Eingeschränkt",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Die Teilnehmer können nur an Anrufen teilnehmen, aber keine Audio-, Video- oder Bildschirmübertragung aktivieren, bis ein Moderator diese Berechtigungen manuell erteilt.",
    "Participants get a reduced feature set until a moderator manually grants additional permissions." : "Die Teilnehmer erhalten einen reduzierten Funktionsumfang, bis die Moderation manuell zusätzliche Berechtigungen erteilt.",
    "Advanced permissions" : "Erweiterte Berechtigungen",
    "Edit permissions" : "Berechtigungen bearbeiten",
    "Conversation settings" : "Unterhaltungseinstellungen",
    "Basic Info" : "Basisinformationen",
    "Personal" : "Persönlich",
    "Moderation" : "Moderation",
    "Setup overview" : "Einstellungsübersicht",
    "Live transcription" : "Live-Transkription",
    "Live transcriptions app is not installed" : "Die Live-Transkriptions-App ist nicht installiert",
    "Enable live transcription" : "Live-Transkription aktivieren",
    "Breakout Rooms" : "Breakout-Räume",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Bots",
    "Danger zone" : "Gefahrenzone",
    "Archive conversation" : "Unterhaltung archivieren",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Archivierte Unterhaltungen werden standardmäßig aus der Unterhaltungsliste ausgeblendet. Sie werden jedoch weiterhin angezeigt, wenn du nach dem Unterhaltungsnamen suchst oder auf eine Liste archivierter Unterhaltungen zugreifst.",
    "Do you really want to leave \"{displayName}\"?" : "Möchtest du wirklich \"{displayName}\" verlassen?",
    "You can archive this conversation instead." : "Die Unterhaltung kann stattdessen archiviert werden.",
    "Leave conversation" : "Unterhaltung verlassen",
    "You need to promote a new moderator before you can leave the conversation" : "Du musst einen neuen Moderator bestimmen, bevor du die Unterhaltung verlassen kannst.",
    "Delete conversation" : "Unterhaltung löschen",
    "Do you really want to delete \"{displayName}\"?" : "Möchtest du wirklich \"{displayName}\" löschen?",
    "Error while deleting conversation" : "Fehler beim Löschen der Unterhaltung",
    "Delete all chat messages" : "Alle Chatnachrichten löschen",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Willst du wirklich alle Nachrichten in \"{displayName}\" löschen?",
    "Error while clearing chat history" : "Fehler beim Löschen des Chatverlaufs",
    "Be careful, these actions cannot be undone." : "Bitte vorsichtig sein, diese Aktionen können nicht rückgängig gemacht werden.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Nachdem du eine Unterhaltung verlassen hast, ist eine Einladung erforderlich, um einer bereits geschlossenen Unterhaltung wieder beizutreten. Einer noch geöffneten Unterhaltung kannst du jederzeit wieder beitreten.",
    "Permanently delete this conversation." : "Die Unterhaltung endgültig löschen.",
    "Delete chat messages" : "Chatnachrichten löschen",
    "Permanently delete all the messages in this conversation." : "Alle Nachrichten in dieser Unterhaltung endgültig löschen.",
    "Custom expiration time" : "Benutzerdefinierte Ablaufzeit",
    "Message expiration disabled" : "Nachrichtenablauf deaktiviert",
    "Message expiration set: {duration}" : "Nachrichtenablauf eingestellt auf: {duration}",
    "Error when trying to set message expiration" : "Fehler beim Festlegen des Nachrichtenablaufs",
    "Message expiration" : "Nachrichtenablauf",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Chatnachrichten können nach einer bestimmten Zeit gelöscht werden. Hinweis: Im Chat freigegebene Dateien werden für den Besitzer nicht gelöscht, aber sie werden nicht mehr in der Unterhaltung freigegeben.",
    "Set message expiration" : "Ablauf der Nachricht festlegen",
    "Current message expiration" : "Ablauf der aktuellen Nachricht",
    "Password copied to clipboard" : "Passwort in die Zwischenablage kopiert",
    "Password could not be copied" : "Passwort konnte nicht kopiert werden",
    "Guest access" : "Gastzugriff",
    "Breakout rooms are not allowed in public conversations." : "Gruppenräume sind bei öffentlichen Gesprächen nicht gestattet.",
    "Allow guests to join this conversation via link" : "Gästen die Teilnahme an dieser Unterhaltung per Link erlauben",
    "Password protection" : "Passwortschutz",
    "This conversation is password-protected. Guests need password to join" : "Diese Unterhaltung ist passwortgeschützt. Gäste brauchen ein Passwort um teilzunehmen",
    "Password protection is needed for public conversations" : "Passwortschutz ist für öffentliche Gespräche erforderlich",
    "Set a password" : "Passwort setzen",
    "Change password" : "Passwort ändern",
    "Enter new password" : "Neues Passwort eingeben",
    "Save password" : "Passwort speichern",
    "Copy password" : "Passwort kopieren",
    "Guests are allowed to join this conversation via link" : "Gäste dürfen dieser Unterhaltung über einen Link beitreten",
    "Guests are not allowed to join this conversation" : "Gäste dürfen dieser Unterhaltung nicht beitreten",
    "Resend invitations" : "Einladungen erneut senden",
    "This conversation is open to both registered users and users created with the Guests app" : "Diese Unterhaltung ist sowohl für registrierte Benutzer, als auch für Benutzer, die mit der Gast-App erstellt wurden, geöffnet",
    "This conversation is open to registered users" : "Diese Unterhaltung ist für registrierte Benutzer geöffnet",
    "This conversation is limited to the current participants" : "Diese Unterhaltung ist auf die bisherigen Teilnehmer beschränkt",
    "You opened the conversation to both registered users and users created with the Guests app" : "Du hast diese Unterhaltung sowohl für registrierte Benutzer, als auch für Benutzer, die mit der Gast-App erstellt wurden, geöffnet.",
    "Error occurred when opening or limiting the conversation" : "Beim Öffnen oder Einschränken der Unterhaltung ist ein Fehler aufgetreten",
    "Open conversation to registered users, showing it in search results" : "Unterhaltung für registrierte Benutzer öffnen und in den Suchergebnissen anzeigen",
    "Also open to users created with the Guests app" : "Auch für Gäste, die mit der Gast-App erstellt wurden, geöffnet",
    "Open conversation" : "Unterhaltung öffnen",
    "Set language spoken in calls" : "Die in Telefonaten gesprochene Sprache festlegen",
    "Languages could not be loaded" : "Sprachen konnten nicht geladen werden",
    "Loading languages …" : "Lade Sprachen …",
    "Invalid language" : "Ungültige Sprache",
    "Default language (English)" : "Standardsprache (Englisch)",
    "Default live transcription language set" : "Standard Live-Transkriptionssprache eingestellt",
    "Live transcription language set: {languageName}" : "Eingestellte Live-Transkriptionssprache: {languageName}",
    "Error when trying to set live transcription language" : "Fehler beim Einstellen der Live-Transkriptionssprache",
    "Start time: {date}" : "Startzeit: {date}",
    "Start time has been updated" : "Startzeit wurde angepasst",
    "Error occurred while updating start time" : "Beim Aktualisieren der Startzeit ist ein Fehler aufgetreten",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Durch Aktivieren der Lobby werden Nicht-Moderatoren aus dem laufenden Anruf entfernt.",
    "Enable lobby, restricting the conversation to moderators" : "Aktivieren der Lobby, beschränke die Unterhaltung auf die Moderatoren.",
    "Meeting start time" : "Meeting Startzeit",
    "Start time (optional)" : "Startzeit (optional)",
    "Import email participants" : "E-Mail-Teilnehmer importieren",
    "You can import a list of email participants from a CSV file." : "Eine Liste von E-Mail-Teilnehmern kann aus einer CSV-Datei importiert werden.",
    "Poll drafts" : "Umfrageentwürfe",
    "Browse poll drafts" : "Umfrageentwürfe durchsuchen",
    "Error occurred when locking the conversation" : "Beim Sperren der Unterhaltung ist ein Fehler aufgetreten",
    "Error occurred when unlocking the conversation" : "Beim Entsperren der Unterhaltung ist ein Fehler aufgetreten",
    "Lock conversation" : "Unterhaltung sperren",
    "This will also terminate the ongoing call." : "Dadurch wird auch der laufende Anruf beendet. ",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Die Unterhaltung sperren, um zu verhindern, dass jemand Nachrichten postet oder Anrufe startet",
    "Edit" : "Bearbeiten",
    "More information" : "Weitere Informationen",
    "Delete" : " Löschen",
    "Add new bridged channel to current conversation" : "Neuen Einbindungs-Kanal für die aktuelle Unterhaltung hinzufügen",
    "unknown state" : "unbekannter Zustand",
    "running" : "läuft",
    "not running, check Matterbridge log" : "Nicht aktiv, bitte das Matterbridge-Protokoll prüfen",
    "not running" : "läuft nicht",
    "Bridge saved" : "Brücke gespeichert",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Mit Matterbridge kannst du Brücken-Kanäle von verschiedenen Instant-Messaging-Systemen verbinden.",
    "More info on Matterbridge" : "Weitere Informationen über Matterbridge",
    "Messaging systems" : "Messaging-Systeme",
    "Enable bridge" : "Einbindung aktivieren",
    "Show Matterbridge log" : "Zeige das Matterbridge Log",
    "Log content" : "Log-Inhalt",
    "Only moderators are allowed to mention @all" : "Nur Moderatoren dürfen @all erwähnen",
    "All participants are allowed to mention @all" : "Alle Teilnehmer dürfen @all erwähnen",
    "Participants are now allowed to mention @all." : "Teilnehmer dürfen nun @all erwähnen.",
    "Mentioning @all has been limited to moderators." : "Erwähnung von @all wurde auf Moderatoren beschränkt.",
    "Allow participants to mention @all" : "Teilnehmer dürfen @all erwähnen",
    "Mention permissions" : "Erwähnungsberechtigungen",
    "Notifications" : "Benachrichtigungen",
    "Notify about calls in this conversation" : "Über Anrufe in dieser Unterhaltung benachrichtigen",
    "Important conversation" : "Wichtige Unterhaltung",
    "\"Do not disturb\" user status is ignored for important conversations" : "\"Nicht stören\"-Benutzerstatus wird für wichtige Unterhaltungen ignoriert",
    "Sensitive conversation" : "Sensible Unterhaltung",
    "Message preview will be disabled in conversation list and notifications" : "Die Nachrichtenvorschau wird in der Unterhaltungsliste und den Benachrichtigungen deaktiviert",
    "Recording consent is required for calls in this conversation" : "Zur Teilnahme an dieser Unterhaltung ist die Einwilligung zur Aufzeichnung erforderlich",
    "Recording consent is not required for calls in this conversation" : "Zur Teilnahme an dieser Unterhaltung ist die Einwilligung zur Aufzeichnung nicht erforderlich",
    "Recording consent requirement was updated" : "Die Einstellungen zum Erfordernis der Zustimmung zur Aufzeichnung wurde aktualisiert.",
    "Error occurred while updating recording consent" : "Beim Aktualisieren der Einstellung zur Zustimmung zur Aufzeichnung ist ein Fehler aufgetreten.",
    "Recording Consent" : "Einwilligung zur Aufzeichnung",
    "Recording consent cannot be changed once a call or breakout session has started." : "Die Einwilligung zur Aufzeichnung kann nicht mehr geändert werden, sobald ein Unterhaltung oder eine Breakout-Sitzung begonnen hat.",
    "Require recording consent before joining call in this conversation" : "Zur Teilnahme an dieser Unterhaltung ist die Zustimmung zur Aufzeichnung erforderlich.",
    "Recording consent is required for all calls" : "Für alle Unterhaltungen ist eine Zustimmung zur Aufzeichnung erforderlich",
    "SIP dial-in is now possible without PIN requirement" : "SIP-Einwahl ist jetzt ohne PIN möglich",
    "SIP dial-in is now enabled" : "Die SIP-Einwahl ist jetzt aktiviert",
    "SIP dial-in is now disabled" : "Die SIP-Einwahl ist jetzt deaktiviert",
    "Error occurred when enabling SIP dial-in" : "Beim Aktivieren der SIP-Einwahl ist ein Fehler aufgetreten",
    "Error occurred when disabling SIP dial-in" : "Beim Deaktivieren der SIP-Einwahl ist ein Fehler aufgetreten",
    "Phone and SIP dial-in" : "Telefon- und SIP-Einwahl",
    "Enable phone and SIP dial-in" : "Telefon- und SIP-Einwahl aktivieren",
    "Allow to dial-in without a PIN" : "Einwahl ohne PIN erlauben",
    "Ongoing" : "Laufend",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n Person hat angenommen","%n Personen haben angenommen"],
    "_%n person declined_::_%n people declined_" : ["%n Person hat abgelehnt","%n Personen haben abgelehnt"],
    "_and %n other attachment_::_and %n other attachments_" : ["und %n anderer Anhang","und %n andere Anhänge"],
    "With {displayName}" : "Mit {displayName}",
    "In {conversation}" : "In {conversation}",
    "View attachment" : "Anhang ansehen",
    "Join" : "Beitreten",
    "View conversation" : "Unterhaltung anzeigen",
    "View event on Calendar" : "Termin im Kalender anzeigen",
    "Error while creating the conversation" : "Fehler beim Erstellen der Unterhaltung",
    "Hello, {displayName}" : "Hallo {displayName}",
    "Start meeting now" : "Besprechung jetzt beginnen",
    "Give your meeting a title" : "Gib deiner Besprechung einen Titel",
    "Create and copy link" : "Link erstellen und teilen",
    "Create a new conversation" : "Neue Unterhaltung erstellen",
    "Join open conversations" : "Offener Unterhaltung beitreten",
    "Call a phone number" : "Eine Telefonnummer anrufen",
    "Scroll backward" : "Rückwärts scrollen",
    "Scroll forward" : "Vorwärts scrollen",
    "Schedule meetings" : "Besprechungen planen",
    "You don't have any upcoming meetings" : "Du hast keine bevorstehenden Besprechungen",
    "Calendar events with a conversation link as the location are shown here" : "Hier werden Kalenderereignisse mit einem Unterhaltungslink als Ort angezeigt",
    "Open calendar" : "Kalender öffnen",
    "Unread mentions" : "Ungelesene Erwähnungen",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "Nachrichten, in denen du erwähnt wurdest, werden hier angezeigt. Du kannst Personen erwähnen, indem du @ gefolgt von deren Namen eingibst",
    "Upcoming reminders" : "Anstehende Erinnerungen",
    "Message reminders" : "Nachrichtenerinnerungen",
    "Set a reminder on a message to be notified" : "Eine Erinnerung für eine Nachricht festlegen, um benachrichtigt zu werden",
    "Start a group conversation" : "Gruppenunterhaltung beginnen",
    "Create conversation" : "Unterhaltung erstellen",
    "Enter your name" : "Gib deinen Namen ein",
    "Submit name and join" : "Namen übermitteln und beitreten",
    "Do you already have an account?" : "Hast du bereits ein Konto?",
    "Log in" : "Anmelden",
    "Error while verifying uploaded file" : "Fehler bei der Überprüfung der hochgeladenen Datei",
    "Uploaded file is verified" : "Hochgeladene Datei wurde überprüft",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "Das Inhaltsformat besteht aus kommagetrennten Werten (CSV):<br/>- Eine Kopfzeile ist erforderlich und muss mit <samp>\"Name\",\"E-Mail\"</samp> oder nur <samp>\"E-Mail\"</samp> übereinstimmen. <br/>- Ein Eintrag pro Zeile (z. B. <samp>\"Max Mustermann\", \"max@beispiel.de\"</samp>)",
    "Participants added successfully" : "Teilnehmer hinzugefügt",
    "Error while adding participants" : "Fehler beim Hinzufügen von Teilnehmern",
    "Import a file" : "Eine Datei importieren",
    "Browse" : "Durchsuchen",
    "Verifying uploaded file …" : "Überprüfe hochgeladene Datei …",
    "This might take a moment" : "Dies kann einen Moment dauern",
    "Send invitations" : "Einladungen senden",
    "_%n invalid email_::_%n invalid emails_" : ["%n ungültige E-Mail","%n ungültige E-Mails"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n E-Mail ist bereits importiert oder ein Duplikat","%n E-Mails sind bereits importiert oder Duplikate"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["%n Einladung kann verschickt werden","%n Einladungen können verschickt werden"],
    "An error occurred while calling a phone number" : "Es ist ein Fehler beim Anrufen einer Telefonnummer aufgetreten",
    "Phone number could not be called: {error}" : "Die Telefonnummer konnte nicht angerufen werden: {error}",
    "Phone number could not be called" : "Die Telefonnummer konnte nicht angerufen werden",
    "Search participants or phone numbers" : "Teilnehmer oder Telefonnummern suchen",
    "Creating the conversation …" : "Die Unterhaltung wird erstellt …",
    "Mark as read" : "Als gelesen markieren",
    "Mark as unread" : "Als ungelesen markieren",
    "Remove from favorites" : "Aus den Favoriten entfernen",
    "Add to favorites" : "Zu den Favoriten hinzufügen",
    "Unarchive conversation" : "Unterhaltung dearchivieren",
    "Ignore \"Do not disturb\"" : "\"Nicht stören\"-Modus ignorieren",
    "You need to promote a new moderator before you can leave the conversation." : "Du musst einen neuen Moderator bestimmen, bevor du die Unterhaltung verlassen kannst.",
    "New tag" : "Neues Schlagwort",
    "Tag name" : "Schlagwortname",
    "Conversation actions" : "Unterhaltungsaktionen",
    "Tags" : "Schlagworte",
    "Notify about calls" : "Über Anrufe benachrichtigen",
    "Hide message text" : "Nachrichtentext ausblenden",
    "Remove all tags" : "Alle Schlagworte entfernen",
    "Rename tag" : "Schlagwort umbenennen",
    "Delete tag" : "Schlagwort löschen",
    "Do you really want to delete \"{name}\"? Conversations with this tag will be moved to \"Other\"." : "Soll \"{name}\" gelöscht werden? Unterhaltungen mit diesem Schlagwort werden dann nach \"Sonstiges\" verschoben.",
    "Move up" : "Nach oben verschieben",
    "Move down" : "Nach unten verschieben",
    "Pending invitations" : "Ausstehende Einladungen",
    "Join conversations from other servers" : "Unterhaltungen von anderen Servern beitreten",
    "From {user} at {remoteServer}" : "Von {user} auf {remoteServer}",
    "Decline invitation" : "Einladung ablehnen",
    "Accept invitation" : "Einladung annehmen",
    "No pending invitations" : "Keine ausstehenden Einladungen",
    "Home" : "Startseite",
    "Unread" : "Ungelesen",
    "Mentions" : "Erwähnungen",
    "Meetings" : "Besprechungen",
    "Sort conversations" : "Unterhaltungen sortieren",
    "By recent activity" : "Nach neuesten Aktivitäten",
    "Alphabetically" : "Alphabetisch",
    "Do not group by type" : "Nicht nach Typ gruppieren",
    "Show private ones first" : "Private zuerst zeigen",
    "Show group ones first" : "Gruppe zuerst zeigen",
    "No followed threads" : "Keine nachverfolgten Themen",
    "No matches found" : "Keine Übereinstimmungen gefunden",
    "No conversations found" : "Keine Unterhaltungen gefunden",
    "You have no archived conversations." : "Du hast keine archivierten Unterhaltungen",
    "Subscribe to an existing thread or start your own." : "Ein existierendes Thema abonnieren, oder ein eigenes Thema beginnen.",
    "You have no unread mentions." : "Du hast keine ungelesenen Erwähnungen.",
    "You have no unread messages." : "Du hast keine ungelesenen Nachrichten.",
    "An error occurred while performing the search" : "Es ist ein Fehler beim Suchen aufgetreten",
    "Conversation list" : "Unterhaltungsliste",
    "Filter conversations by" : "Unterhaltungen filtern nach",
    "Unread messages" : "Ungelesene Nachrichten",
    "Meeting conversations" : "Besprechungsunterhaltungen",
    "Clear filters" : "Filter zurücksetzen",
    "New personal note" : "Neue persönliche Notiz",
    "SIP backend is not installed" : "SIP-Backend ist nicht installiert",
    "Back to conversations" : "Zurück zu den Unterhaltungen",
    "Threads" : "Themen",
    "Archived conversations" : "Archivierte Unterhaltungen",
    "Clear filter" : "Filter zurücksetzen",
    "Show more threads" : "Mehr Themen anzeigen",
    "App settings" : "App-Einstellungen",
    "Users" : "Benutzer",
    "Groups" : "Gruppen",
    "Teams" : "Teams",
    "Federated users" : "Federierte Benutzer",
    "New private conversation" : "Neue private Unterhaltung",
    "Other sources" : "Andere Quellen",
    "Open conversations" : "Offene Unterhaltungen",
    "No search results" : "Keine Suchergebnisse",
    "Users, groups and teams" : "Personen, Gruppen und Teams",
    "Users and groups" : "Benutzer und Gruppen",
    "Users and teams" : "Personen und Teams",
    "Groups and teams" : "Gruppen und Teams",
    "New group conversation" : "Neue Gruppenunterhaltung",
    "The meeting will start soon" : "Das Meeting beginnt bald",
    "This meeting is scheduled for {startTime}" : "Dieses Meeting ist geplant für {startTime}",
    "You are currently waiting in the lobby" : "Du wartest derzeit in der Lobby",
    "Enable noise suppression" : "Geräuschunterdrückung aktivieren",
    "Reduce background noises for better voice quality" : "Hintergrundgeräusche für eine bessere Sprachqualität reduzieren",
    "Basic" : "Standard",
    "Advanced" : "Erweitert",
    "Enable echo cancellation" : "Echounterdrückung aktivieren",
    "Minimize echo effect from own surrounding" : "Echoeffekt aus der eigenen Umgebung minimieren",
    "Enable auto gain control" : "Regelung der automatischen Verstärkung aktivieren",
    "Dynamically adjust microphone volume for consistent level" : "Die Mikrofonlautstärke dynamisch anpassen, um einen konstanten Pegel zu halten",
    "Select microphone" : "Mikrofon auswählen",
    "No microphone available" : "Kein Mikrofon verfügbar",
    "Select speaker" : "Lautsprecher auswählen",
    "No speaker available" : "Kein Lautsprecher verfügbar",
    "Select camera" : "Kamera auswählen",
    "No camera available" : "Keine Kamera verfügbar",
    "Select a device" : "Ein Gerät auswählen",
    "Playing …" : "Wiedergabe …",
    "Test speakers" : "Lautsprecher testen",
    "Test" : "Test",
    "Devices" : "Geräte",
    "Backgrounds" : "Hintergründe",
    "No audio" : "Kein Audio",
    "No camera" : "Keine Kamera",
    "Display video as you will see it (mirrored)" : "Video so anzeigen, wie du es sehen wirst (gespiegelt)",
    "Display video as others will see it" : "Video so anzeigen, wie andere es sehen",
    "Calls are not supported in your browser" : "Anrufe werden von deinem Browser nicht unterstützt",
    "Access to microphone is only possible with HTTPS" : "Zugriff auf Mikrofon ist nur über HTTPS möglich",
    "Access to microphone was denied" : "Zugriff auf Mikrofon wurde verweigert",
    "Error while accessing microphone" : "Fehler beim Zugriff auf das Mikrofon",
    "Access to camera is only possible with HTTPS" : "Zugriff auf Kamera ist nur über HTTPS möglich",
    "The call is being recorded." : "Der Anruf wird aufgezeichnet.",
    "The call might be recorded." : "Die Unterhaltung wird möglicherweise aufgezeichnet.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "Die Aufnahme kann deine Stimme sowie Video von der Kamera und einer Bildschirmfreigabe beinhalten. Vor der Teilnahme am Anruf ist dein Einverständnis hierzu erforderlich.",
    "Give consent to the recording of this call" : "Stimme bitte der Aufzeichnung dieser Unterhaltung zu",
    "You can only join a voice room via a call." : "Du kannst einem Sprachraum nur über einen Anruf beitreten.",
    "Show more info" : "Weitere Informationen anzeigen",
    "Audio is not available" : "Audio ist nicht verfügbar",
    "Video is not available" : "Video ist nicht verfügbar",
    "Start recording immediately with the call" : "Aufzeichnung sofort mit dem Anruf starten",
    "Recording backend is not installed" : "Aufnahme-Backend ist nicht installiert",
    "Notify all participants about this call" : "Alle Teilnehmer über diesen Anruf benachrichtigen",
    "Apply settings" : "Einstellungen anwenden",
    "Select virtual office background" : "Büro als virtuellen Hintergrund auswählen",
    "Select virtual home background" : "Zuhause als virtuellen Hintergrund auswählen",
    "Select virtual abstract background" : "Abstraktion als virtuellen Hintergrund auswählen",
    "Select virtual beach background" : "Strand als virtuellen Hintergrund auswählen",
    "Select virtual park background" : "Park als virtuellen Hintergrund auswählen",
    "Select virtual theater background" : "Theater als virtuellen Hintergrund auswählen",
    "Select virtual library background" : "Bibliothek als virtuellen Hintergrund auswählen",
    "Select virtual space station background" : "Raumstation als virtuellen Hintergrund auswählen",
    "Error while uploading the file" : "Fehler beim Hochladen der Datei",
    "Select a file" : "Eine Datei wählen",
    "Invalid path selected" : "Ungültiger Pfad ausgewählt",
    "Select virtual background from file {fileName}" : "Virtuellen Hintergrund von Datei {fileName} auswählen",
    "Blur" : "Verwischen",
    "Upload" : "Hochladen",
    "Files" : "Dateien",
    "(editing)" : "(bearbeiten)",
    "(edited)" : "(Bearbeitet)",
    "The message has expired or has been deleted" : "Die Nachricht ist abgelaufen oder wurde gelöscht",
    "Cancel quote" : "Zitieren abbrechen",
    "24 hours" : "24 Stunden",
    "7 days" : "7 Tage",
    "30 days" : "30 Tage",
    "Until unpin" : "Bis zum Ablösen",
    "Clear reminder – {timeLocale}" : "Erinnerung löschen – {timeLocale}",
    "Edited by {actor}" : "Bearbeitet von {actor}",
    "Pinned by you" : "Angeheftet von dir",
    "Pinned by {actor}" : "Angeheftet von {actor}",
    "Until {absoluteDate}" : "Bis zum {absoluteDate}",
    "Message text copied to clipboard" : "Nachrichteninhalt wurde in die Zwischenablage kopiert",
    "Message text could not be copied" : "Nachrichteninhalt konnte nicht kopiert werden",
    "Message forwarded to \"Note to self\"" : "Nachricht weitergeleitet an \"Notiz an mich\"",
    "Error while forwarding message to \"Note to self\"" : "Fehler beim Weiterleiten der Nachricht an \"Notiz an mich\"",
    "A reminder was successfully removed" : "Erinnerung wurde entfernt",
    "Error occurred when removing a reminder" : "Beim Entfernen einer Erinnerung ist ein Fehler aufgetreten",
    "A reminder was successfully set at {datetime}" : "Eine Erinnerung wurde für {datetime} erstellt.",
    "Error occurred when creating a reminder" : "Beim Erstellen einer Erinnerung ist ein Fehler aufgetreten",
    "Add a reaction to this message" : "Dieser Nachricht eine Reaktion hinzufügen",
    "Reply" : "Antworten",
    "More actions" : "Weitere Aktionen",
    "Set reminder" : "Erinnerung erstellen",
    "Pin message" : "Nachricht anheften",
    "Unpin message" : "Nachricht ablösen",
    "Reply privately" : "Privat antworten",
    "Edit message" : "Nachricht bearbeiten",
    "Copy message" : "Nachricht kopieren",
    "Copy message link" : "Nachrichtenlink kopieren",
    "Go to file" : "Zur Datei wechseln",
    "Download file" : "Datei herunterladen",
    "Go to thread" : "Zu Thema gehen",
    "Edit thread details" : "Themendetails bearbeiten",
    "Forward message" : "Nachricht weiterleiten",
    "Translate" : "Übersetzen",
    "Set custom reminder" : "Benutzerdefinierte Erinnerung erstellen",
    "Keep pinned for" : "Angeheftet lassen für",
    "Set custom period" : "Benutzerdefinierten Zeitraum eingeben",
    "Close reactions menu" : "Menü für Reaktionen schließen",
    "React with {emoji}" : "Mit {emoji} reagieren",
    "React with another emoji" : "Mit einem anderen Emoji reagieren",
    "Choose a conversation to forward the selected message." : "Eine Unterhaltung auswählen um die ausgewählte Nachricht weiterzuleiten.",
    "Error while forwarding message" : "Fehler beim Weiterleiten der Nachricht",
    "The message has been forwarded to {selectedConversationName}" : "Die Nachricht wurde an {selectedConversationName} weitergleitet",
    "Dismiss" : "Ausblenden",
    "Go to conversation" : "Zur Unterhaltung gehen",
    "Detect language" : "Sprache erkennen",
    "The message could not be translated" : "Die Nachricht konnte nicht übersetzt werden",
    "Translation copied to clipboard" : "Übersetzung wurde in die Zwischenablage kopiert",
    "Translation could not be copied" : "Übersetzung konnte nicht kopiert werden",
    "Translate message" : "Nachricht übersetzen",
    "Source language to translate from" : "Ausgangssprache, aus der übersetzt werden soll ",
    "Translate from" : "Übersetzen von",
    "Target language to translate into" : "Zielsprache, in die übersetzt werden soll",
    "Translate to" : "Übersetzen in",
    "Translating" : "Übersetze",
    "This translation is AI generated and may contain mistakes." : "Diese Übersetzung ist KI-generiert und kann Fehler enthalten.",
    "Copy translated text" : "Übersetzen Text kopieren",
    "Error when scheduling the message" : "Fehler beim Planen des Nachrichtenversands",
    "Reschedule" : "Umplanen",
    "Send now" : "Jetzt senden",
    "Choose a time" : "Eine Zeit wählen",
    "Send at custom time" : "Zur benutzerdefinierten Zeit senden",
    "Will be sent without notification" : "Wird ohne Benachrichtigung gesendet",
    "Message read by everyone who shares their reading status" : "Nachricht wird von allen gelesen, die deinen Lesestatus teilen",
    "Message sent" : "Nachricht wurde gesendet",
    "Sent without notification" : "Ohne Benachrichtigung gesendet",
    "Deleting message" : "Löschen der Nachricht",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "Nachricht gelöscht, aber ein Bot oder Matterbridge ist konfiguriert und die Nachricht wurde unter Umständen bereits an andere Dienste verteilt",
    "Message deleted successfully" : "Nachricht gelöscht",
    "Message could not be deleted because it is too old" : "Nachricht konnte nicht gelöscht werden, da sie zu alt ist.",
    "Only normal chat messages can be deleted" : "Nur normale Chatnachrichten können gelöscht werden",
    "An error occurred while deleting the message" : "Es ist ein Fehler beim Löschen der Nachricht aufgetreten",
    "Pinned" : "Angeheftet",
    "Your browser does not support playing audio files" : "Der Browser unterstützt nicht das Abspielen von Audio-Dateien",
    "Contact" : "Kontakt",
    "{stack} in {board}" : "{stack} in {board}",
    "Deck Card" : "Deck-Karte",
    "Remove {fileName}" : "Entferne {fileName}",
    "Open this location in OpenStreetMap" : "Diesen Ort in OpenStreetMap öffnen",
    "_%n reply_::_%n replies_" : ["%n Antwort","%n Antworten"],
    "Sending message" : "Nachricht wird gesendet",
    "Failed to send the message. Click to try again" : "Nachricht konnte nicht gesendet werden. Klicke, um es erneut zu versuchen.",
    "Not enough free space to upload file" : "Nicht genügend freier Speicherplatz zum Hochladen der Datei",
    "You cannot send messages to this conversation at the moment" : "Du kannst derzeit keine Nachrichten an diese Unterhaltung senden",
    "Could not update the message" : "Nachricht konnte nicht aktualisiert werden",
    "Reply to thread \"{threadTitle}\"" : "Antwort auf das Thema \"{threadTitle}\"",
    "_You voted • %n vote_::_You voted • %n votes_" : ["Du hast abgestimmt • %n Stimme","Du hast abgestimmt • %n Stimmen"],
    "You voted" : "Du hast abgestimmt",
    "_Click to vote • %n vote_::_Click to vote • %n votes_" : ["Zum Abstimmen klicken • %n Stimme","Zum Abstimmen klicken • %n Stimmen"],
    "Click to vote" : "Zum Abstimmen klicken",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Umfrageentwurf • %n Option","Umfrageentwurf • %n Optionen"],
    "_%n vote_::_%n votes_" : ["%n Stimme","%n Stimmen"],
    "Edit poll draft" : "Umfrageentwurf bearbeiten",
    "Delete poll draft" : "Umfrageentwurf löschen",
    "Open poll" : "Offene Umfrage",
    "Closed poll" : "Geschlossene Umfrage",
    "See results" : "Ergebnisse anzeigen",
    "Reactions" : "Reaktionen",
    "No permission to post reactions in this conversation" : "Keine Berechtigung zum Veröffentlichen von Reaktionen in dieser Unterhaltung",
    "and {participant}" : "und {participant}",
    "_and %n other participant_::_and %n other participants_" : ["und %n weiterer Teilnehmer","und %n weitere Teilnehmer"],
    "Show all reactions" : "Alle Reaktionen anzeigen",
    "Add more reactions" : "Weitere Reaktionen hinzufügen",
    "Show or collapse system messages" : "Systemnachrichten anzeigen oder zuklappen",
    "No messages" : "Keine Nachrichten",
    "All messages have expired or have been deleted." : "Alle Nachrichten sind abgelaufen oder wurden gelöscht.",
    "Generate summary with AI" : "Zusammenfassung mit KI erstellen",
    "{author} (pinned by you)" : "{author} (Von dir angeheftet)",
    "{author} (pinned by {actor})" : "{author} (Angeheftet von {actor})",
    "Unpin" : "Ablösen",
    "Cancel search" : "Suche abbrechen",
    "Add a phone number" : "Eine Telefonnummer hinzufügen",
    "Error: A password is required to create the conversation." : "Fehler: Ein Passwort ist erforderlich, um die Unterhaltung zu erstellen.",
    "All set, the conversation \"{conversationName}\" was created." : "Alles erledigt, die Unterhaltung \"{conversationName}\" wurde erstellt.",
    "Create a new group conversation" : "Neue Gruppenunterhaltung erstellen",
    "Add participants" : "Teilnehmer hinzufügen",
    "Maximum length exceeded ({maxlength} characters)" : "Maximale Länge überschritten ({maxlength} Zeichen)",
    "Conversation type" : "Unterhaltungstyp",
    "Default parameters are:" : "Standardparameter sind:",
    "These settings can be changed once the conversation is created." : "Diese Einstellungen können geändert werden, sobald die Unterhaltung erstellt wurde.",
    "Conversation visibility" : "Sichtbarkeit der Unterhaltung",
    "Allow guests to join via link" : "Gästen die Teilnahme per Link erlauben",
    "Enter password" : "Passwort eingeben",
    "This conversation has been locked" : "Diese Unterhaltung wurde gesperrt",
    "No permission to post messages in this conversation" : "Keine Berechtigung zum Veröffentlichen von Nachrichten in dieser Unterhaltung",
    "Joining conversation …" : "Unterhaltung beitreten …",
    "Write a message without notification" : "Eine Nachricht ohne Benachrichtigung schreiben",
    "Create a thread silently" : "Ein Thema stillschweigend erstellen",
    "Create a thread" : "Ein Thema erstellen",
    "Send message silently" : "Nachricht still senden",
    "Send message" : "Nachricht senden",
    "Send without notification" : "Ohne Benachrichtigung senden",
    "The participant will not be notified about new messages" : "Der Teilnehmer wird über neue Nachrichten nicht benachrichtigt",
    "Participants will not be notified about new messages" : "Teilnehmer werden über neue Nachrichten nicht benachrichtigt",
    "Message will be sent {datetimeString}" : "Nachricht wird gesendet um {datetimeString}",
    "Thread title is required" : "Ein Thementitel ist erforderlich",
    "Message text is required" : "Ein Nachrichtentext ist erforderlich",
    "The message could not be edited" : "Die Nachricht konnte nicht bearbeitet werden",
    "File to share" : "Zu teilende Datei",
    "File upload is not available in this conversation" : "Das Hochladen von Dateien ist in dieser Unterhaltung nicht verfügbar",
    "Message was successfully scheduled" : "Nachrichtenversand wurde geplant",
    "Add emoji" : "Emoji hinzufügen",
    "Adding a mention will only notify users who did not read the message." : "Hinzufügen einer Erwähnung benachrichtigt nur Benutzer, die die Nachricht noch nicht gelesen haben.",
    "Thread title" : "Thementitel",
    "Send later" : "Später senden",
    "Show scheduled messages" : "Geplante Nachrichten ansehen",
    "Cancel editing" : "Bearbeitung abbrechen",
    "Schedule message" : "Nachrichtenversand planen",
    "{user} is out of office and might not respond." : "{user} ist nicht im Büro und antwortet möglicherweise nicht.",
    "Absence period: {startDate} - {endDate}" : "Abwesenheitszeitraum: {startDate} - {endDate}",
    "Replacement:" : "Ersatz:",
    "Share from {nextcloud}" : "Von {nextcloud} teilen",
    "Share from Files" : "Aus Dateien heraus teilen",
    "Share files to the conversation" : "Dateien mit der Unterhaltung teilen",
    "Upload from device" : "Von Gerät hochladen",
    "Create new poll" : "Neue Umfrage erstellen",
    "Smart picker" : "Intelligente Auswahl",
    "Record voice message" : "Sprachnachricht aufnehmen",
    "End recording and send" : "Aufnahme beenden und senden",
    "Dismiss recording" : "Aufnahme verwerfen",
    "Access to the microphone was denied" : "Zugriff auf das Mikrofon wurde verweigert",
    "Microphone either not available or disabled in settings" : "Mikrofon ist entweder nicht verfügbar oder in den Einstellungen deaktiviert",
    "Error while recording audio" : "Fehler bei der Audioaufnahme",
    "Voice message {time} ({conversation})" : "Sprachnachricht {time} ({conversation})",
    "Generating summary of unread messages …" : "Zusammenfassung ungelesener Nachrichten wird erstellt …",
    "Summary is AI generated and might contain mistakes" : "Die Zusammenfassung wird von einer KI erstellt und kann Fehler enthalten",
    "Error occurred during a summary generation" : "Es ist ein Fehler beim Erstellen einer Zusammenfassung aufgetreten",
    "New file" : "Neue Datei",
    "Blank" : "Leer",
    "Error while creating file" : "Fehler beim Erstellen der Datei",
    "Create and share a new file" : "Erstellen und teile eine neue Datei",
    "Name of the new file" : "Name der neuen Datei",
    "Create file" : "Datei erstellen",
    "Someone is typing …" : "Jemand schreibt …",
    "{user1} is typing …" : "{user1} schreibt …",
    "{user1} and {user2} are typing …" : "{user1} und {user2} schreiben …",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} und {user3} schreiben …",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} and %n weiterer schreiben …","{user1}, {user2}, {user3} and %n weitere schreiben …"],
    "Add more files" : "Weitere Dateien hinzufügen",
    "Send" : "Senden",
    "In this conversation <strong>{user}</strong> can:" : "In dieser Unterhaltung kann <strong>{user}</strong>:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Standardberechtigungen für Teilnehmer in <strong>{conversationName}</strong> bearbeiten",
    "Start a call" : "Einen Anruf starten",
    "Skip the lobby" : "Die Lobby überspringen",
    "Can post messages" : "Kann Nachrichten senden",
    "Can post messages and reactions" : "Kann Nachrichten und Reaktionen posten",
    "Can add reactions" : "Kann Reaktionen hinzufügen",
    "Enable the microphone" : "Das Mikrofon aktivieren",
    "Enable the camera" : "Die Kamera aktivieren",
    "Share the screen" : "Den Bildschirm teilen",
    "Update permissions" : "Berechtigungen aktualisieren",
    "Updating permissions" : "Aktualisiere Berechtigungen",
    "No poll drafts" : "Keine Umfrageentwürfe",
    "There is no poll drafts yet saved for this conversation" : "Für diese Unterhaltung sind noch keine Umfrageentwürfe gespeichert",
    "Create poll in {name}" : "Umfrage erstellen in {name}",
    "Create poll" : "Umfrage erstellen",
    "Error while importing poll" : "Fehler beim Importieren der Umfrage",
    "Question" : "Frage",
    "Ask a question" : "Eine Frage stellen",
    "Import draft from file" : "Entwurf aus Datei importieren",
    "Answers" : "Antworten",
    "Answer {option}" : "Antwort {option}",
    "Delete poll option" : "Umfrage-Option löschen",
    "Add answer" : "Antwort hinzufügen",
    "Settings" : "Einstellungen",
    "Anonymous poll" : "Anonyme Umfrage",
    "Multiple answers" : "Mehrere Antworten",
    "Save as draft" : "Als Entwurf speichern",
    "Export draft to file" : "Entwurf in Datei exportieren",
    "_Final results • %n vote_::_Final results • %n votes_" : ["Endergebnisse • %n Stimme","Endergebnisse • %n Stimmen"],
    "_%n vote • Your vote is anonymous_::_%n votes • Your vote is anonymous_" : ["%n Stimme • Deine Stimme ist anonym","%n Stimmen • Deine Stimme ist anonym"],
    "Your vote is anonymous" : "Deine Stimme ist anonym",
    "You voted for this option" : "Du hast für diese Option gestimmt",
    "End poll" : "Umfrage beenden",
    "Change your vote" : "Ändere deine Stimmabgabe",
    "Withdraw vote" : "Stimme zurückziehen",
    "Results" : "Ergebnisse",
    "Download as spreadsheet" : "Als Tabelle herunterladen",
    "Download as CSV" : "Als CSV herunterladen",
    "Voted participants" : "Gewählte Teilnehmer",
    "Send a message to \"{roomName}\"" : "Eine Nachricht an \"{roomName}\" senden",
    "Hide list of participants" : "Teilnehmerliste verbergen",
    "Show list of participants" : "Teilnehmerliste anzeigen",
    "Assistance requested in {roomName}" : "Unterstützung angefordert in {roomName}",
    "The message was sent to \"{roomName}\"" : "Die Nachricht wurde an \"{roomName}\" gesendet",
    "Dismiss request for assistance" : "Bitte um Unterstützung ablehnen",
    "Send message to room" : "Nachricht an Raum senden",
    "Back to main room" : "Zurück zum Hauptraum",
    "Back to your room" : "Zurück zu deinen Raum",
    "Message all rooms" : "Nachricht an alle Räume",
    "Start session" : "Sitzung starten",
    "Start a call before you start a breakout room session" : "Einen Anruf starten bevor du eine Gruppenraumsitzung beginnst",
    "Stop session" : "Sitzung beenden",
    "The message was sent to all breakout rooms" : "Die Nachricht wurde an alle Gruppenräume gesendet.",
    "Send a message to all breakout rooms" : "Nachricht an alle Gruppenräume senden",
    "Breakout rooms are not started" : "Gruppenräume sind nicht gestartet",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "Anrufe ohne Hochleistungs-Backend können Verbindungsprobleme und eine hohe Gerätebelastung verursachen. {linkstart}Mehr erfahren{linkend}",
    "Talk setup incomplete" : "Talk-Einrichtung unvollständig",
    "Disable lobby" : "Lobby deaktivieren",
    "Settings for participant \"{user}\"" : "Einstellungen für den Teilnehmer \"{user}\"",
    "Participant \"{user}\"" : "Teilnehmer \"{user}\"",
    "moderator" : "Moderator",
    "bot" : "Bot",
    "guest" : "Gast",
    "Ringing …" : "Klingeln …",
    "Call rejected" : "Anruf abgelehnt",
    "{time} talking …" : "{time} im Gespräch …",
    "{time} talking time" : "{time} Gesprächsdauer",
    "Raised their hand" : "Hat die Hand gehoben",
    "Joined with video" : "Mit Video beigetreten",
    "Joined via phone" : "Mit Telefon beigetreten",
    "Joined with audio" : "Mit Audio beigetreten",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Der Text muss weniger als oder gleich {maxLength} Zeichen lang sein. Dein aktueller Text ist {charactersCount} Zeichen lang.",
    "Remove group and members" : "Gruppe und Mitglieder entfernen",
    "Remove team and members" : "Team und Mitglieder entfernen",
    "Remove participant" : "Teilnehmer entfernen",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Soll die Gruppe \"{displayName}\" und ihre Mitglieder aus dieser Unterhaltung entfernt werden?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Soll das Team \"{displayName}\" und seine Mitglieder aus dieser Unterhaltung entfernt werden?",
    "Do you really want to remove {displayName} from this conversation?" : "Soll {displayName} aus dieser Unterhaltung entfernt werden?",
    "Notification was sent to {displayName}" : "Benachrichtigung wurde an {displayName} gesendet",
    "Could not send notification to {displayName}" : "Benachrichtigung konnte nicht an  {displayName} versandt werden",
    "Permissions granted to {displayName}" : "Berechtigungen für {displayName} gewährt",
    "Could not modify permissions for {displayName}" : " Die Berechtigungen für {displayName} konnten nicht geändert werden",
    "Permissions removed for {displayName}" : "Berechtigungen für {displayName} entzogen",
    "Permissions set to default for {displayName}" : "Berechtigungen für {displayName} auf Standard gesetzt",
    "Phone number could not be hung up" : "Telefonnummer konnte nicht aufgelegt werden",
    "Phone number could not be put on hold" : "Telefonnummer konnte nicht in die Warteschleife gelegt werden",
    "Phone number could not be muted" : "Telefonnummer konnte nicht stummgeschaltet werden",
    "Phone number could not be unmuted" : "Stummschaltung für Telefonnummer konnte nicht aufgehoben werden",
    "DTMF message could not be sent" : "MFW-Nachricht konnte nicht gesendet werden",
    "Phone number copied to clipboard" : "Telefonnummer in die Zwischenablage kopiert",
    "Phone number could not be copied" : "Telefonnummer konnte nicht kopiert werden",
    "in the lobby" : "In der Lobby",
    "Dial out phone" : "Telefon wählen",
    "Hang up phone" : "Telefon auflegen",
    "Move back to lobby" : "Zurück zur Lobby",
    "Move to conversation" : "Zur Unterhaltung wechseln",
    "Dial-in PIN" : "Einwahl-PIN",
    "Demote from moderator" : "Moderator absetzen",
    "Promote to moderator" : "Zum Moderator ernennen",
    "Resend invitation" : "Einladung erneut senden",
    "Send call notification" : "Sende Anrufbenachrichtigung",
    "Dial out phone number" : "Ausgehende Telefonnummer",
    "Resume call for phone number" : "Anruf fortsetzen für Telefonnummer",
    "Put phone number on hold" : "Telefonnummer in die Warteschleife legen",
    "Unmute phone number" : "Stummschaltung der Telefonnummer aufheben",
    "Mute phone number" : "Telefonnummer stummschalten",
    "Copy phone number" : "Telefonnummer kopieren",
    "Reset custom permissions" : "Benutzerdefinierte Berechtigungen zurücksetzen",
    "Grant all permissions" : "Alle Berechtigungen gewähren",
    "Remove all permissions" : "Alle Berechtigungen entziehen",
    "Also ban from this conversation" : "Auch für diese Unterhaltung sperren",
    "Internal note (reason to ban)" : "Interne Notiz (Grund der Sperrung)",
    "Remove" : "Entfernen",
    "Permissions modified for {displayName}" : "Berechtigungen  für {displayName} geändert",
    "Add users, groups or teams" : "Personen, Gruppen oder Teams hinzufügen",
    "Add users or groups" : "Benutzer oder Gruppen hinzufügen",
    "Add users or teams" : "Personen oder Teams hinzufügen",
    "Add users" : "Benutzer hinzufügen",
    "Add groups or teams" : "Gruppen oder Teams hinzufügen",
    "Add groups" : "Gruppen hinzufügen",
    "Add teams" : "Teams hinzufügen",
    "Add other sources" : "Andere Quellen hinzufügen",
    "Add emails" : "E-Mails hinzufügen",
    "Integrations" : "Einbindungen",
    "Add federated users" : "Federated-Benutzer hinzufügen",
    "Searching …" : "Suche …",
    "Search for more users" : "Nach weiteren Benutzern suchen",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Du kannst Teilnehmende über Namen, E-Mail-Adresse oder Federated-Cloud-ID suchen oder hinzufügen",
    "Search or add participants" : "Teilnehmer suchen oder hinzufügen",
    "Invitation was sent to {actorId}" : "Einladung wurde an {actorId} gesendet",
    "An error occurred while adding the participants" : "Es ist ein Fehler beim Hinzufügen der Teilnehmer aufgetreten.",
    "A new group conversation with selected participant will be created" : "Es wird eine neue Gruppenunterhaltung mit dem ausgewählten Teilnehmer erstellt",
    "Participants" : "Teilnehmer",
    "Pinned by a deleted user" : "Angeheftet von einem gelöschten Benutzer",
    "Participants ({count})" : "Teilnehmer ({count})",
    "Open chat" : "Chat öffnen",
    "You have new unread messages in the chat." : "Du hast neue ungelesene Nachrichten im Chat.",
    "You have been mentioned in the chat." : "Du wurdest im Chat erwähnt.",
    "Search messages" : "Nachrichten suchen",
    "Chat" : "Chat",
    "Details" : "Details",
    "Shared items" : "Freigegebene Elemente",
    "Search in {name}" : "Suche in {name}",
    "Threads in {name}" : "Themen in {name}",
    "{actor} in {conversation}" : "{actor} in {conversation}",
    "Search messages …" : "Suche Nachrichten  …",
    "Search options" : "Suchoptionen",
    "From User" : "Von Benutzer",
    "Since" : "Seit",
    "Until" : "Bis",
    "No results found" : "Keine Ergebnisse gefunden",
    "Load more results" : "Weitere Ergebnisse laden",
    "Recent threads" : "Neueste Themen",
    "Projects" : "Projekte",
    "No shared items" : "Keine geteilten Elemente",
    "Thread notifications" : "Thread-Benachrichtigungen",
    "Thread actions" : "Themenaktionen",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Zu einer Unterhaltung verlinken",
    "No open conversations found" : "Keine offenen Unterhaltungen gefunden",
    "Either there are no open conversations or you joined all of them." : "Entweder gibt es keine offenen Unterhaltungen oder du bist bereits allen beigetreten.",
    "Check spelling or use complete words." : "Überprüfe die Rechtschreibung oder verwende vollständige Wörter.",
    "Search conversations or users" : "Nach Unterhaltungen oder Benutzern suchen",
    "Select conversation" : "Unterhaltung auswählen",
    "Number length is not valid" : "Nummernlänge ist nicht gültig",
    "Region code is not valid" : "Vorwahl ist ungültig",
    "Number length is too short" : "Nummernlänge ist zu kurz",
    "Number length is too long" : "Nummernlänge ist zu lang",
    "Number is not valid" : "Nummer ist nicht gültig",
    "Phone numbers" : "Telefonnummern",
    "Display name: {name}" : "Anzeigename: {name}",
    "Edit display name" : "Anzeigename bearbeiten",
    "Display name (required)" : "Anzeigename (erforderlich)",
    "Save name" : "Namen speichern",
    "I picked message bubbles" : "Ich habe Sprechblasen ausgewählt",
    "I picked the list style" : "Ich habe den Listenstil ausgewählt",
    "Error while setting personal setting" : "Fehler beim Festlegen der persönlichen Einstellung",
    "Error while saving sounds setting" : "Fehler beim Speichern der Toneinstellung",
    "Compact conversations list" : "Unterhaltungsliste verkleinern",
    "Chat appearance" : "Chat-Darstellung",
    "Messages list" : "Nachrichtenliste",
    "Message bubbles" : "Sprechblasen",
    "Play sounds when participants join or leave a call" : "Töne abspielen, wenn Teilnehmer einem Anruf beitreten oder verlassen",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "Derzeit aufgrund technischer Einschränkungen durch den Hersteller nicht auf iPhone und iPad verfügbar",
    "Notification settings" : "Benachrichtigungseinstellungen",
    "Sounds for chat and call notifications" : "Töne für Chat- und Anrufbenachrichtigungen",
    "Invalid language ({languageId})" : "Ungültige Sprache ({languageId})",
    "Default language" : "Standardsprache",
    "Default language ({languageName})" : "Standardsprache ({languageName})",
    "Error when trying to load the available live translation languages" : "Fehler beim Versuch, die verfügbaren Live-Übersetzungssprachen zu laden",
    "Error when trying to set live translation language" : "Fehler beim Versuch, eine Live-Übersetzungssprache festzulegen",
    "Set language used to show the transcriptions" : "Sprache festlegen, die zur Anzeige der Transkriptionen verwendet wird",
    "Select location for attachments" : "Speicherort für Anhänge auswählen",
    "Error while setting attachment folder" : "Fehler beim Festlegen des Ordners für Anhänge",
    "Error while setting read status privacy" : "Fehler beim Setzen des Lesestatus Privatsphäre",
    "Error while setting typing status privacy" : "Fehler beim Festlegen des Datenschutzes für den Eingabestatus",
    "Error while setting default media state" : "Fehler beim Setzen des Standard-Medienstatus",
    "Turn camera and microphone off by default" : "Kamera und Mikrofon standardmäßig ausschalten",
    "Blur camera background by default" : "Kamerahintergrund standardmäßig verwischen",
    "Skip device preview before joining a call" : "Gerätevorschau vor dem Beitritt zu einer Unterhaltung überspringen",
    "Camera will be turned off when joining. Always shown if recording consent is required." : "Beim Beitritt wird die Kamera ausgeschaltet. Dies wird immer angezeigt, wenn eine Einverständniserklärung erforderlich ist.",
    "Appearance & Sounds" : "Aussehen & Töne",
    "Privacy" : "Datenschutz",
    "Send read receipts" : "Lesebestätigungen senden",
    "When off, all read statuses will be hidden" : "Im ausgeschalteten Zustand werden alle Lesestatus ausgeblendet",
    "Share typing status" : "Schreibstatus teilen",
    "When off, all typing indicators will be hidden" : "Im ausgeschalteten Zustand werden alle Schreibanzeigen ausgeblendet",
    "Attachments folder" : "Ordner für Anhänge",
    "Toggle full screen" : "Vollbild umschalten",
    "Return to Home screen" : "Zum Startbildschirm zurückkehren",
    "Search" : "Suche",
    "Shortcuts while in a chat" : "Tastaturkürzel während eines Chats",
    "Focus the chat input" : "Chat-Eingabe fokussieren",
    "Unfocus the chat input to use shortcuts" : "Chat-Eingabe in den Hintergrund",
    "Edit your last message" : "Deine letzte Nachricht bearbeiten",
    "Shortcuts while in a call" : "Tastaturkürzel während eines Anrufs",
    "Camera on and off" : "Kamera ein- und ausschalten",
    "Microphone on and off" : "Mikrofon ein- und ausschalten",
    "Raise or lower hand" : "Hand heben oder senken",
    "Push to talk or push to mute" : "Zum Sprechen oder Stummschalten drücken",
    "Zoom-in / zoom-out a screen share" : "Vergrößern/Verkleinern einer Bildschirmfreigabe",
    "Mouse wheel" : "Mausrad",
    "Start call silently" : "Anruf stumm beginnen",
    "Start call" : "Anruf starten",
    "End call" : "Anruf beenden",
    "The server was updated, you cannot start or join a call." : "Der Server wurde aktualisiert, Du kannst keinen Anruf starten oder daran teilnehmen.",
    "This call has just ended" : "Dieser Anruf wurde gerade beendet",
    "You will be able to join the call only after a moderator starts it." : "Du kannst dem Anruf erst beitreten, nachdem ein Moderator ihn gestartet hat.",
    "End call for everyone" : "Anruf für alle beenden",
    "Starting the recording" : "Aufnahme wird gestartet",
    "Recording" : "Aufnahme",
    "The call has been running for one hour." : "Der Anruf läuft seit einer Stunde.",
    "Cancel recording start" : "Start der Aufnahme abbrechen",
    "Stop recording" : "Aufnahme stoppen",
    "Raise hand" : "Hand heben",
    "Raise hand (R)" : "Hand heben (R)",
    "Lower hand" : "Hand herunternehmen",
    "Lower hand (R)" : "Hand herunternehmen (R)",
    "Send a reaction" : "Reaktion senden",
    "React with {reaction}" : "Reagiere mit {reaction}",
    "All tasks done!" : "Alle Aufgaben erledigt!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} von %n Aufgabe","{done} von %n Aufgaben"],
    "Add participants to this call" : "Teilnehmer zu diesem Anruf hinzufügen",
    "_%n participant in call_::_%n participants in call_" : ["%n Anrufteilnehmer","%n Anrufteilnehmer"],
    "Scheduled messages" : "Geplante Nachrichten",
    "You are not allowed to enable screensharing" : "Du bist nicht berechtigt, die Bildschirmfreigabe zu aktivieren",
    "No screensharing" : "Keine Bildschirmfreigabe",
    "Screensharing options" : "Optionen für Bildschirmübertragung",
    "Enable screensharing" : "Bildschirmübertragung aktivieren",
    "Bad sent video and screen quality." : "Schlechte Video- und Bildschirm-Sendequalität.",
    "Bad sent screen quality." : "Schlechte Bildschirm-Sendequalität.",
    "Bad sent video quality." : "Schlechte Video-Sendequalität",
    "Bad sent audio, video and screen quality." : "Schlechte Audio-, Video- und Bildschirm-Sendequalität.",
    "Bad sent audio and screen quality." : "Schlechte Audio- und Bildschirm-Sendequalität.",
    "Bad sent audio and video quality." : "Schlechte Audio- und Video-Sendequalität.",
    "Bad sent audio quality." : "Schlechte Audio-Sendequalität",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Deine Internetverbindung oder dein Computer ist ausgelastet und andere Teilnehmer können dich möglicherweise nicht verstehen und nicht sehen. Versuche, die Hintergrundunschärfe oder deine Videofreigabe zu deaktivieren, um die Bildschirmübertragung zu verbessern.",
    "Disable background blur" : "Hintergrund ohne Unschärfe",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Deine Internetverbindung oder dein Computer sind ausgelastet und andere Teilnehmer können dich möglicherweise nicht verstehen und nicht sehen.  Versuche deine Videofreigabe zu deaktivieren, um die Übertragung zu verbessern.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Deine Internetverbindung oder dein Computer sind ausgelastet und andere Teilnehmer können deinen Bildschirm möglicherweise nicht sehen.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Deine Internetverbindung oder dein Computer sind ausgelastet und andere Teilnehmer können dich möglicherweise nicht sehen.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Deine Internetverbindung oder dein Computer sind ausgelastet und andere Teilnehmer können dich möglicherweise nicht verstehen und nicht sehen.  Versuche die Hintergrundunschärfe oder die Hintergrundunschärfe zu deaktivieren, um die Bildschirmübertragung zu verbessern.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Deine Internetverbindung oder dein Computer sind ausgelastet und andere Teilnehmer können dich möglicherweise nicht verstehen und nicht sehen. Versuche, deine Videofreigabe zu deaktivieren, um die Bildschirmübertragung zu verbessern.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Deine Internetverbindung oder dein Computer sind ausgelastet und andere Teilnehmer können dich möglicherweise nicht verstehen und nicht sehen. Versuche deine Bildschirmfreigabe zu deaktivieren, um die Übertragung zu verbessern.",
    "Disable screenshare" : "Bildschirmübertragung deaktivieren",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Deine Internetverbindung oder dein Computer sind ausgelastet und andere Teilnehmer können dich möglicherweise nicht verstehen und nicht sehen. Versuche die Hintergrundunschärfe oder deine Videofreigabe zu deaktivieren, um die Bildschirmübertragung zu verbessern.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Deine Internetverbindung oder dein Computer sind ausgelastet und andere Teilnehmer können dich möglicherweise nicht verstehen und nicht sehen. Versuche, deine Videofreigabe zu deaktivieren, um die Übertragung zu verbessern.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Deine Internetverbindung oder dein Computer sind ausgelastet und andere Teilnehmer können dich möglicherweise nicht verstehen.",
    "Screen sharing is not supported by your browser." : "Dieser Browser unterstützt das Teilen des Bildschirms nicht",
    "Screen sharing requires the page to be loaded through HTTPS." : "Bildschirmteilen erfordert dass die Seite über HTTPS geladen wird.",
    "Screensharing requires the page to be loaded through HTTPS." : "Das Übertragen des Bildschirms erfordert das Laden der Seite über HTTPS.",
    "An error occurred while starting screensharing." : "Es ist ein Fehler beim Start der Bildschirmübertragung aufgetreten.",
    "Select virtual background" : "Virtuellen Hintergrund auswählen",
    "Show your screen" : "Deinen Bildschirm übertragen",
    "Stop screensharing" : "Bildschirmübertragung beenden",
    "Mute others" : "Andere Stummschalten",
    "Start recording" : "Aufnahme beginnen",
    "Set up breakout rooms" : "Gruppenräume einrichten",
    "Download attendance list" : "Anwesenheitsliste herunterladen",
    "Open Calendar" : "Kalender öffnen",
    "Remove participant {name}" : "Teilnehmer {name} entfernen",
    "Would you like to delete this conversation?" : "Soll diese Unterhaltung gelöscht werden?",
    "_This conversation will be automatically deleted for everyone after %n day of inactivity._::_This conversation will be automatically deleted for everyone after %n days of inactivity._" : ["Diese Unterhaltung wird nach %n Tag Inaktivität für alle gelöscht","Diese Unterhaltung wird nach %n Tagen Inaktivität für alle gelöscht"],
    "Are you sure you want to delete this conversation?" : "Soll diese Unterhaltung gelöscht werden?",
    "Delete now" : "Jetzt löschen",
    "Keep" : "Behalten",
    "Open dialpad" : "Wählfeld öffnen",
    "Select a region" : "Eine Region auswählen",
    "Local time: {time}" : "Ortszeit: {time}",
    "Scheduled {datetime}" : "Geplant {datetime}",
    "Scheduled for {datetime}" : "Geplant für {datetime}",
    "Search …" : "Suche …",
    "Message without mention" : "Nachricht ohne Erwähnung",
    "Mention myself" : "Mich selbst erwähnen",
    "Mention everyone" : "Alle erwähnen",
    "Select a conversation" : "Eine Unterhaltung auswählen",
    "Select a mode" : "Einen Modus auswählen",
    "You do not have permissions to access this conversation." : "Du hast nicht die Berechtigung auf diese Unterhaltung zuzugreifen",
    "Join a different conversation or start a new one." : "Nimm an einer anderen Unterhaltung teil oder beginne eine neue.",
    "The conversation does not exist" : "Die Unterhaltung existiert nicht",
    "Join a conversation or start a new one!" : "Trete einer Unterhaltung bei oder starte eine neue!",
    "This conversation was opened in another tab. The current server version does not support opening a conversation in multiple tabs." : "Diese Unterhaltung wurde in einem anderen Tab geöffnet. Die aktuelle Serverversion unterstützt das Öffnen einer Konversation in mehreren Tabs nicht.",
    "Creating and joining a conversation with \"{userid}\"" : "Eine Unterhaltung mit \"{userid}\" erstellen und daran teilnehmen",
    "Join a conversation or start a new one" : "Trete einer Unterhaltung bei oder starte eine neue",
    "Error while joining the conversation" : "Fehler beim Beitreten zur Unterhaltung",
    "Another user" : "Ein anderer Benutzer",
    "Hey! Are you using the list style or message bubbles?" : "Hey! Verwendest du Talk im Listenstil oder mit Sprechblasen?",
    "Nextcloud URL" : "Nextcloud-URL",
    "Nextcloud user" : "Nextcloud-Benutzer",
    "User password" : "Benutzerpasswort",
    "Talk conversation" : "Talk-Unterhaltung",
    "Skip TLS verification" : "TLS-Überprüfung überspringen",
    "Matrix server URL" : "Matrix-Server-URL",
    "User" : "Benutzer",
    "Matrix channel" : "Matrix-Kanal",
    "Mattermost server URL" : "Mattermost-Server-URL",
    "Mattermost user" : "Mattermost-Benutzer",
    "Team name" : "Team-Name",
    "Channel name" : "Kanal-Name",
    "Rocket.Chat server URL" : "Rocket.Chat-Server-URL",
    "User name or email address" : "Benutzername oder E-Mail-Adresse",
    "Rocket.Chat channel" : "Rocket.Chat-Kanal",
    "Zulip server URL" : "Zulip-Server-URL",
    "Bot user name" : "Bot-Benutzername",
    "Bot API key" : "Bot-API-Schlüssel",
    "Zulip channel" : "Zulip-Kanal",
    "API token" : "API-Token",
    "Slack channel" : "Slack-Kanal",
    "Server ID or name" : "Server-ID oder -Name",
    "Channel ID (prefixed with \"ID:\") or name" : "Kanal-ID (mit vorangestelltem \"ID:\") oder Name",
    "Channel" : "Kanal",
    "Login" : "Anmeldung",
    "Chat ID" : "Chat-ID",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "IRC Server-URL (z. B. chat.freenode.net:6667)",
    "Nickname" : "Spitzname",
    "Connection password" : "Verbindungs-Passwort",
    "IRC channel" : "IRC-Kanal",
    "Channel password" : "Kanal-Passwort",
    "NickServ nickname" : "NickServ-Spitzname",
    "NickServ password" : "NickServ-Passwort",
    "Use TLS" : "TLS verwenden",
    "Use SASL" : "SASL verwenden",
    "Tenant ID" : "Tenant-ID",
    "Client ID" : "Client-ID",
    "Team ID" : "Team-ID",
    "Thread ID" : "Thread-ID",
    "XMPP/Jabber server URL" : "XMPP/Jabber Server-URL",
    "MUC server URL" : "MUC-Server-URL",
    "Jabber ID" : "Jabber-ID",
    "Pinned messages" : "Angeheftete Nachrichten",
    "Media" : "Medien",
    "Polls" : "Umfragen",
    "Deck cards" : "Deck-Karten",
    "Voice messages" : "Sprachnachrichten",
    "Locations" : "Orte",
    "Call recordings" : "Anrufaufnahmen",
    "Audio" : "Audio",
    "Show all pinned messages" : "Alle angehefteten Nachrichten anzeigen",
    "Show all media" : "Alle Medien anzeigen",
    "Show all files" : "Alle Dateien anzeigen",
    "Show all polls" : "Alle Umfragen anzeigen",
    "Show all deck cards" : "Alle Deck-Karten anzeigen",
    "Show all voice messages" : "Alle Sprachnachrichten anzeigen",
    "Show all locations" : "Alle Orte anzeigen",
    "Show all call recordings" : "Alle Anrufaufnahmen ansehen",
    "Show all audio" : "Alle Audiodateien anzeigen",
    "Show all other" : "Alle sonstigen anzeigen",
    "Follow conversation settings" : "Unterhaltungseinstellungen folgen",
    "Group" : "Gruppe",
    "Team" : "Team",
    "You reconnected to the call" : "Du hast dich wieder mit dem Anruf verbunden",
    "{actor} reconnected to the call" : "{actor} hat sich wieder mit dem Anruf verbunden",
    "You added {user0} and {user1}" : "Du hast {user0} und {user1} hinzugefügt",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Du hast {user0}, {user1} und %n weiteren Teilnehmer hinzugefügt","Du hast {user0}, {user1} und %n weitere Teilnehmer hinzugefügt"],
    "An administrator added you and {user0}" : "Die Administration hat dich und {user0} hinzugefügt",
    "{actor} added you and {user0}" : "{actor} hat dich und {user0} hinzugefügt",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Die Administration hat dich, {user0} und %n weiteren Teilnehmer hinzugefügt","Die Administration hat dich, {user0} und %n weitere Teilnehmer hinzugefügt"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} hat dich, {user0} und %n weiteren Teilnehmer hinzugefügt","{actor} hat dich, {user0} und %n weitere Teilnehmer hinzugefügt"],
    "An administrator added {user0} and {user1}" : "Die Administration hat {user0} und {user1} hinzugefügt",
    "{actor} added {user0} and {user1}" : "{actor} hat {user0} und {user1} hinzugefügt",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["Die Administration hat {user0}, {user1} und %n weiteren Teilnehmer hinzugefügt","Die Administration hat {user0}, {user1} und %n weitere Teilnehmer hinzugefügt"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} hat {user0}, {user1} und %n weiteren Teilnehmer hinzugefügt","{actor} hat {user0}, {user1} und %n weitere Teilnehmer hinzugefügt"],
    "You removed {user0} and {user1}" : "Du hast {user0} und {user1} entfernt",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Du hast {user0}, {user1} und %n weiteren Teilnehmer entfernt","Du hast {user0}, {user1} und %n weitere Teilnehmer entfernt"],
    "An administrator removed you and {user0}" : "Die Administration hat dich und {user0} entfernt",
    "{actor} removed you and {user0}" : "{actor} hat dich und {user0} entfernt",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Die Administration hat dich, {user0} und %n weiteren Teilnehmer entfernt","Die Administration hat dich, {user0} und %n weitere Teilnehmer entfernt"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} hat dich, {user0} und %n weiteren Teilnehmer entfernt","{actor} hat dich, {user0} und %n weitere Teilnehmer entfernt"],
    "An administrator removed {user0} and {user1}" : "Die Administration hat {user0} und {user1} entfernt",
    "{actor} removed {user0} and {user1}" : "{actor} hat {user0} und {user1} entfernt",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Die Administration hat {user0}, {user1} und %n weiteren Teilnehmer entfernt","Die Administration hat {user0}, {user1} und %n weitere Teilnehmer entfernt"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} hat {user0}, {user1} und %n weiteren Teilnehmer entfernt","{actor} hat {user0}, {user1} und %n weitere Teilnehmer entfernt"],
    "You and {user0} joined the call" : "Du und {user0} sind dem Anruf beigetreten",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Du, {user0} und %n weiterer Teilnehmer sind dem Anruf beigetreten","Du, {user0} und %n weitere Teilnehmer sind dem Anruf beigetreten"],
    "{user0} and {user1} joined the call" : "{user0} und {user1} sind dem Anruf beigetreten",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} und %n weiterer Teilnehmer sind dem Anruf beigetreten","{user0}, {user1} und %n weitere Teilnehmer sind dem Anruf beigetreten"],
    "You and {user0} left the call" : "Du und {user0} haben den Anruf verlassen",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Du, {user0} und %n weiterer Teilnehmer haben den Anruf verlassen","Du, {user0} und %n weitere Teilnehmer haben den Anruf verlassen"],
    "{user0} and {user1} left the call" : "{user0} und {user1} haben den Anruf verlassen",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} und %n weiterer Teilnehmer haben den Anruf verlassen","{user0}, {user1} und %n weitere Teilnehmer haben den Anruf verlassen"],
    "You promoted {user0} and {user1} to moderators" : "Du hast {user0} und {user1} zu Moderatoren ernannt",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Du hast {user0}, {user1} und %n weiteren Teilnehmer zu Moderatoren ernannt","Du hast {user0}, {user1} und %n weitere Teilnehmer zu Moderatoren ernannt"],
    "An administrator promoted you and {user0} to moderators" : "Die Administration hat dich und {user0} zu Moderatoren ernannt",
    "{actor} promoted you and {user0} to moderators" : "{actor} hat dich und {user0} zu Moderatoren ernannt",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Die Administration hat dich, {user0} und %n weiteren Teilnehmer zu Moderatoren ernannt","Die Administration hat dich, {user0} und %n weitere  Teilnehmer zu Moderatoren ernannt"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} hat dich, {user0} und %n weiteren Teilnehmer zu Moderatoren ernannt","{actor} hat dich, {user0} und %n weitere Teilnehmer zu Moderatoren ernannt"],
    "An administrator promoted {user0} and {user1} to moderators" : "Die Administration hat {user0} und {user1} zu Moderatoren ernannt",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} hat {user0} und {user1} zu Moderatoren ernannt",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Die Administration hat {user0}, {user1} und %n weiteren Teilnehmer zu Moderatoren ernannt","Die Administration hat {user0}, {user1} und %n weitere Teilnehmer zu Moderatoren ernannt"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} hat {user0}, {user1} und %n weiteren Teilnehmer zu Moderatoren befördert","{actor} hat {user0}, {user1} und %n weitere Teilnehmer zu Moderatoren ernannt"],
    "You demoted {user0} and {user1} from moderators" : "Du hast {user0} und {user1} von der Moderation abberufen",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Du hast {user0}, {user1} und %n weiteren Teilnehmer von der Moderation abberufen","Du hast {user0}, {user1} und %n weitere Teilnehmer von der Moderation abberufen"],
    "An administrator demoted you and {user0} from moderators" : "Die Administration hat dich und {user0} von der Moderation abberufen",
    "{actor} demoted you and {user0} from moderators" : "{actor} hat dich und {user0} von der Moderation abberufen",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["Die Administration hat dich, {user0} und %n weiteren Teilnehmer von Moderatoren abberufen","Die Administration hat dich, {user0} und %n weitere Teilnehmer von Moderatoren abberufen"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} hat dich, {user0} und %n weiteren Teilnehmer von der Moderation abberufen","{actor} hat dich, {user0} und %n weitere Teilnehmer von der Moderation abberufen"],
    "An administrator demoted {user0} and {user1} from moderators" : "Die Administration hat {user0} und {user1} von der Moderation abberufen",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} hat {user0} und {user1} von der Moderation abberufen",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["Die Administration hat {Benutzer0}, {Benutzer1} und %n weiteren Teilnehmer von der Moderation abberufen","Die Administration hat {Benutzer0}, {Benutzer1} und %n weitere Teilnehmer von der Moderation abberufen"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} hat {Benutzer0}, {Benutzer1} und %n weiteren Teilnehmer von der Moderation abberufen","{actor} hat {Benutzer0}, {Benutzer1} und %n weitere Teilnehmer von der Moderation abberufen"],
    "You:" : "Du:",
    "You: {lastMessage}" : "Du: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The server was updated." : "Der Server wurde aktualisiert.",
    "(edited by you)" : "(Von dir bearbeitet)",
    "(edited by a deleted user)" : "(Von einem gelöschten Benutzer bearbeitet)",
    "(edited by {moderator})" : "(Bearbeitet von {moderator})",
    "The recording failed. Please contact your administrator." : "Die Aufnahme ist fehlgeschlagen. Bitte wende dich an deine Administration.",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Du versuchst, an einer Unterhaltung teilzunehmen, während du in einem anderen Fenster oder Gerät eine aktive Sitzung hast. Dies wird derzeit von Nextcloud Talk nicht unterstützt. Was möchtest du tun?",
    "Leave this page" : "Diese Seite verlassen",
    "Join here" : "Hier beitreten",
    "Deck card has been posted to {conversation}" : "Deckkarte wurde nach {conversation} gepostet",
    "An error occurred while posting deck card to conversation" : "Es ist ein Fehler beim Posten der Deckkarte an die Unterhaltung aufgetreten",
    "Post to a conversation" : "An eine Unterhaltung posten",
    "Post to conversation" : "An eine Unterhaltung posten",
    "Location has been posted to {conversation}" : "Der Standort wurde nach {conversation} gepostet",
    "An error occurred while posting location to conversation" : "Es ist ein Fehler beim Posten des Ortes an die Unterhaltung aufgetreten.",
    "Share to a conversation" : "Mit einer Unterhaltung teilen",
    "Share to conversation" : "Mit der Unterhaltung teilen",
    "In conversation" : "In einer Unterhaltung",
    "Search in conversation: {conversation}" : "Suche in Unterhaltung: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "Deine Anfragen werden derzeit aufgrund des Brute-Force-Schutzes gedrosselt",
    "Error while clearing conversation history" : "Fehler beim Löschen des Unterhaltungsverlaufs",
    "Error occurred while allowing guests" : "Es ist ein Fehler beim Zulassen von Gästen aufgetreten",
    "Error occurred while disallowing guests" : "Fehler beim Nichtzulassen von Gästen",
    "Error occurred when restricting the conversation to moderator" : "Fehler beim Beschränken der Unterhaltung auf den Moderator aufgetreten",
    "Error occurred when opening the conversation to everyone" : "Beim Öffnen der Unterhaltung für alle ist ein Fehler aufgetreten",
    "Conversation password has been saved" : "Passwort für diese Unterhaltung wurde gespeichert",
    "Conversation password has been removed" : "Passwort für diese Unterhaltung wurde entfernt",
    "Error occurred while saving conversation password" : "Es ist ein Fehler beim Speichern des Passworts für die Unterhaltung aufgetreten",
    "Call recording is starting." : "Gesprächsaufnahme startet.",
    "Call recording stopped while starting." : "Unterhaltungsaufnahme beim Start angehalten.",
    "Call recording stopped. You will be notified once the recording is available." : "Anrufaufzeichnung angehalten. Du wirst benachrichtigt, sobald die Aufnahme zur Verfügung steht.",
    "Conversation picture set" : "Unterhaltungsbild festgelegt",
    "Conversation picture deleted" : "Unterhaltungsbild gelöscht",
    "Could not delete the conversation picture" : "Unterhaltungsbild konnte nicht gelöscht werden",
    "Could not remove the automatic expiration" : "Der automatische Ablauf konnte nicht entfernt werden",
    "Could not post message: {errorMessage}" : "Nachricht konnte nicht gesendet werden: {errorMessage}",
    "Participant is banned successfully" : "Teilnehmer wurde gesperrt",
    "Error while banning the participant" : "Fehler beim Sperren des Teilnehmers",
    "An error occurred while fetching the participants" : "Es ist ein Fehler beim Abrufen der Teilnehmer aufgetreten",
    "Could not send invitation to {actorId}" : "Einladung konnte nicht an {actorId} gesendet werden",
    "Invitations sent" : "Einladungen gesendet",
    "Error occurred when sending invitations" : "Beim Senden der Einladungen ist ein Fehler aufgetreten",
    "Failed to join the conversation." : "Beitreten zur Unterhaltung fehlgeschlagen",
    "An error occurred while creating breakout rooms" : "Es ist ein Fehler beim Erstellen von Breakout-Räumen aufgetreten.",
    "An error occurred while re-ordering the attendees" : "Es ist ein Fehler beim Neuordnen der Teilnehmer aufgetreten.",
    "An error occurred while deleting breakout rooms" : "Es ist ein Fehler beim  Löschen von Breakout-Räumen aufgetreten.",
    "An error occurred while starting breakout rooms" : "Es ist ein Fehler beim  Starten vom Breakout-Räumen aufgetreten.",
    "An error occurred while stopping breakout rooms" : "Es ist ein Fehler beim  Stoppen von Breakout-Räumen aufgetreten.",
    "An error occurred while sending a message to the breakout rooms" : "Es ist ein Fehler beim Senden einer Nachricht an die Gruppenräume aufgetreten.",
    "An error occurred while requesting assistance" : "Es ist ein Fehler beim Anfordern der Unterstützung aufgetreten.",
    "An error occurred while resetting the request for assistance" : "Es ist ein Fehler beim Zurücksetzen der Hilfeanfrage aufgetreten.",
    "An error occurred while joining breakout room" : "Es ist ein Fehler beim Beitritt zum Gruppenraumraum aufgetreten",
    "Failed to rename the thread" : "Thema konnte nicht umbenannt werden",
    "Error renaming tag" : "Fehler beim Umbenennen des Schlagwortes",
    "Error deleting tag" : "Fehler beim Löschen des Schlagwortes",
    "Error reordering tags" : "Fehler beim Umsortieren der Schlagworte",
    "Error fetching upcoming events" : "Fehler beim Abrufen der bevorstehenden Termine",
    "Error fetching upcoming reminders" : "Fehler beim Abrufen der anstehenden Erinnerungen",
    "An error occurred while accepting an invitation" : "Es ist ein Fehler bei der Annahme einer Einladung aufgetreten",
    "An error occurred while rejecting an invitation" : "Es ist ein Fehler bei der Zurückweisung einer Einladung aufgetreten",
    "{guest} (guest)" : "{guest} (Gast)",
    "Poll draft has been saved" : "Umfrageentwurf wurde gespeichert",
    "An error occurred while saving the draft" : "Beim Speichern des Entwurfs ist ein Fehler aufgetreten",
    "An error occurred while submitting your vote" : "Es ist ein Fehler beim Absenden deiner Stimme aufgetreten.",
    "An error occurred while ending the poll" : "Es ist ein Fehler beim Beenden der Umfrage aufgetreten.",
    "An error occurred while deleting the poll draft" : "Es ist ein Fehler beim Löschen des Umfrageentwurfs aufgetreten",
    "Poll \"{name}\" was created by {user}. Click to vote" : "Umfrage \"{name}\" wurde von {user} erstellt. Klicke, um abzustimmen",
    "Failed to add reaction" : "Hinzufügen der Reaktion fehlgeschlagen",
    "Failed to remove reaction" : "Entfernen der Reaktion fehlgeschlagen",
    "The server is in maintenance mode." : "Der Server befindet sich im Wartungsmodus.",
    "Federated server was updated." : "Der Federated-Server wurde aktualisiert.",
    "Error while uploading file \"{fileName}\"" : "Fehler beim Hochladen der Datei \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "Nicht genügend freier Speicherplatz zum Hochladen von \"{fileName}\"",
    "You are not allowed to share files" : "Keine Berechtigung, Dateien zu teilen",
    "Error while sharing file" : "Fehler beim Teilen der Datei",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Der von dir verwendete Browser wird von Nextcloud Talk nicht vollständig unterstützt. Bitte verwende die neueste Version von Mozilla Firefox, Microsoft Edge, Google Chrome, Opera oder Apple Safari.",
    "_%n hour_::_%n hours_" : ["%n Stunde","%n Stunden"],
    "_%n day_::_%n days_" : ["%n Tag","%n Tage"],
    "_%n week_::_%n weeks_" : ["%n Woche","%n Wochen"],
    "_In %n hour_::_In %n hours_" : ["In %n Stunde","In %n Stunden"],
    "_%n minute _::_%n minutes_" : ["%n Minute","%n Minuten"],
    "In {hours} and {minutes}" : "In {hours} und {minutes}",
    "_In %n minute_::_In %n minutes_" : ["In %n Minute","In %n Minuten"],
    "Later today – {timeLocale}" : "Später heute – {timeLocale}",
    "Set time for later today" : "Zeit für später heute einstellen",
    "Tomorrow – {timeLocale}" : "Morgen – {timeLocale}",
    "Set time for tomorrow" : "Zeit für morgen einstellen",
    "This weekend – {timeLocale}" : "Dieses Wochenende – {timeLocale}",
    "Set time for this weekend" : "Zeit für dieses Wochenende einstellen",
    "Next week – {timeLocale}" : "Nächste Woche – {timeLocale}",
    "Set time for next week" : "Zeit für nächste Woche einstellen",
    "Message link copied to clipboard" : "Nachrichtenlink in die Zwischenablage kopiert",
    "Conversation link copied to clipboard" : "Link zur Unterhaltung in die Zwischenablage kopiert",
    "The link could not be copied" : "Der Link konnte nicht kopiert werden",
    "Error while parsing a PROPFIND error" : "Fehler beim Parsen eines PROPFIND-Fehlers",
    "Sending signaling message has failed" : "Das Senden der Signaling-Nachricht ist fehlgeschlagen",
    "Lost connection to signaling server. Trying to reconnect." : "Verbindung zum Signaling-Server verloren. Es wird versucht, diese wiederherzustellen.",
    "Lost connection to signaling server." : "Verbindung zum Signaling-Server verloren.",
    "Connecting is taking longer than expected …" : "Verbinden dauert länger als erwartet …",
    "Failed to connect. Retrying …" : "Verbindung konnte nicht hergestellt werden. Erneuter Versuch …",
    "Failed to connect. The signaling server may be set up incorrectly" : "Verbindung konnte nicht hergestellt werden Der Signaling-Server könnte falsch eingerichtet sein",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "Der eingerichtete Signalisierungsserver muss aktualisiert werden, damit er mit dieser Version von Talk kompatibel ist. Bitte wende dich an deine Administration.",
    "Please restart the app." : "Bitte die App neu starten.",
    "Please reload the page." : "Bitte die Seite neu laden.",
    "Please try to restart the app." : "Bitte versuche, die App neu zu starten.",
    "Please try to reload the page." : "Bitte versuche, die Seite neu zu laden.",
    "Do not disturb" : "Nicht stören",
    "Away" : "Abwesend",
    "Microphone {number}" : "Mikrofon {number}",
    "Camera {number}" : "Kamera {number}",
    "Speaker {number}" : "Lautsprecher {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Anscheinend sprichst du während du stummgeschaltet bist. Bitte schalte die Stummschaltung aus, damit die Anderen dich hören können.",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Mit mindestens einem Teilnehmer konnte keine Verbindung hergestellt werden. Für dein Szenario wird möglicherweise ein TURN-Server benötigt. Bitte deine Administration, diesen gemäß {linkstart} dieser Dokumentation {linkend} einzurichten.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Dies dauert länger als erwartet. Sind die Zugriffsrechte für Medien bereits erteilt (oder zurückgenommen)? Falls ja, dann starte deinen Browser neu, dann sonst kein Zugriff auf Audio und Video möglich ist",
    "Access to microphone & camera is only possible with HTTPS" : "Zugriff auf Mikrofon & Kamera ist nur über HTTPS möglich",
    "Please move your setup to HTTPS" : "Bitte stelle auf HTTPS um",
    "Access to microphone & camera was denied" : "Zugriff auf Mikrofon & Kamera wurde verweigert",
    "WebRTC is not supported in your browser" : "WebRTC wird von deinem Browser nicht unterstützt",
    "Please use a different browser like Firefox or Chrome" : "Bitte benutze einen anderen Browser, wie z. B. Firefox oder Chrome",
    "Error while accessing microphone & camera" : "Fehler beim Zugriff auf Mikrofon & Kamera",
    "%s Talk on your mobile devices" : "%s Talk auf deinen mobilen Geräte",
    "Join conversations at any time, anywhere, on any device." : "Immer, überall und auf allen Geräten einer Unterhaltung beitreten.",
    "Android app" : "Android-App",
    "iOS app" : "iOS-App",
    "__language_name__" : "Deutsch (Persönlich: Du)",
    "Webhook Demo" : "Webhook-Demo",
    "Call summary (%s)" : "Protokoll (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Der Anruf-Zusammenfassungs-Bot veröffentlicht nach der Unterhaltung eine Übersichtsnachricht, in der alle Teilnehmenden und die Aufgaben aufgeführt sind",
    "Tasks" : "Aufgaben",
    "Notes" : "Notizen",
    "Reports" : "Berichte",
    "Decisions" : "Entscheidungen",
    "Agenda" : "Agenda",
    "Call summary" : "Protokoll",
    "Call summary - {title}" : "Protokoll - {title}",
    "Talk to %s" : "Mit %s sprechen",
    "Talk conversation for event" : "Talk-Unterhaltung für ein Ereignis",
    "Client Push is installed, this improves the performance of desktop clients." : "Client-Push installiert ist. Dies verbessert die Leistung von Desktop-Clients.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push}ist nicht installiert. Dies kann zu Leistungsproblemen bei der Verwendung von Desktop-Clients führen.",
    "Next meeting" : "Nächste Besprechung",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Plane ein Meeting aus deinem Kalender heraus. Ein Talk-Gespräch muss als Ort festgelegt werden, um hier angezeigt zu werden",
    "Join conversations from remote Nextcloud servers" : "Unterhaltungen von entfernten Nextcloud-Servern beitreten",
    "Your default media state has been saved" : "Dein Standard-Medienstatus wurde gespeichert",
    "Set reminder for later today" : "Erinnerung für nachher erstellen",
    "Set reminder for tomorrow" : "Erinnerung für morgen erstellen",
    "Set reminder for this weekend" : "Erinnerung für dieses Wochenende erstellen",
    "Set reminder for next week" : "Erinnerung für nächste Woche erstellen",
    "Generate summary" : "Zusammenfassung erstellen",
    "Open poll • You voted already" : "Offene Umfrage • Du hast bereits abgestimmt",
    "Open poll • Click to vote" : "Offene Umfrage • Klicken, um abzustimmen",
    "Poll • Ended" : "Umfrage・Beendet",
    "Talk recording from {time} ({conversation})" : "Talk-Aufnahme von {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Umfrageergebnis • %n Stimme","Umfrageergebnisse • %n Stimmen"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Offene Umfrage • %n Stimme","Offene Umfrage • %n Stimmen"],
    "Submit vote" : "Stimme übermitteln",
    "Your privacy setting has been saved" : "Deine Datenschutzeinstellungen wurde gespeichert",
    "Your personal setting has been saved" : "Deine persönliche Einstellung wurde gespeichert",
    "Failed to save sounds setting" : "Toneinstellungen konnten nicht gespeichert werden",
    "Sounds setting saved" : "Toneinstellung gespeichert",
    "Always shown if recording consent is required" : "Wird immer angezeigt, wenn eine Zustimmung zur Aufzeichnung erforderlich ist",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Nextcloud Talk wurde aktualisiert. Du kannst keinen Anruf starten oder beitreten.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Du bist der Unterhaltung in einem anderen Fenster oder Gerät beigetreten. Dies wird derzeit von Nextcloud Talk nicht unterstützt, daher wurde diese Sitzung geschlossen.",
    "Nextcloud Talk was updated." : "Nextcloud Talk wurde aktualisiert.",
    "Nextcloud is in maintenance mode." : "Nextcloud befindet sich im Wartungsmodus.",
    "Nextcloud Talk Federation was updated." : "Nextcloud Talk Federation wurde aktualisiert.",
    "Enable live translation" : "Live-Übersetzung aktivieren",
    "_Open poll • %n vote • Your vote is anonymous_::_Open poll • %n votes • Your vote is anonymous_" : ["Offene Umfrage • %n Stimme • Deine Stimme ist anonym","Offene Umfrage • %n Stimmen • Deine Stimme ist anonym"],
    "Open poll • You voted already • Your vote is anonymous" : "Offene Umfrage • Du hast bereits abgestimmt • Deine Stimme ist anonym",
    "Open poll • Your vote is anonymous" : "Offene Umfrage • Deine Stimme ist anonym",
    "I picked list style" : "Ich habe den Listenstil ausgewählt",
    "Hey! Are you using Talk in list style or with message bubbles?" : "Hey! Verwendest du Talk im Listenstil oder mit Sprechblasen?"
},
"nplurals=2; plural=(n != 1);");
